// Capstone Java binding
// By Nguyen Anh Quynh & Dang Hoang Vu,  2013

package capstone;

import com.sun.jna.Structure;
import com.sun.jna.Pointer;
import com.sun.jna.Union;
import com.sun.jna.NativeLong;

import java.util.List;
import java.util.Arrays;

public class X86 {

  // Operand type
  public static final int X86_OP_INVALID = 0;  // Uninitialized.
  public static final int X86_OP_REG = 1;      // Register operand.
  public static final int X86_OP_IMM = 2;      // Immediate operand.
  public static final int X86_OP_FP  = 3;      // Floating-Point immediate operand.
  public static final int X86_OP_MEM = 4;      // Memory operand

  public static class MemType extends Structure {
    public int base;
    public int index;
    public int scale;
    public long disp;

    @Override
    public List getFieldOrder() {
      return Arrays.asList("base", "index", "scale", "disp");
    }
  }

  public static class OpValue extends Union {
    public int reg;
    public long imm;
    public double fp;
    public MemType mem;

    @Override
    public List getFieldOrder() {
      return Arrays.asList("reg", "imm", "fp", "mem");
    }
  }

  public static class Operand extends Structure {
    public int type;
    public OpValue value;

    public void read() {
      super.read();
      if (type == X86_OP_MEM)
        value.setType(MemType.class);
      if (type == X86_OP_FP)
        value.setType(Double.TYPE);
      if (type == X86_OP_IMM)
        value.setType(Long.TYPE);
      if (type == X86_OP_REG)
        value.setType(Integer.TYPE);
      if (type == X86_OP_INVALID)
        return;
      readField("value");
    }

    @Override
    public List getFieldOrder() {
      return Arrays.asList("type", "value");
    }
  }

  public static class UnionOpInfo extends Capstone.UnionOpInfo {
    public byte [] prefix = new byte[5];
    public int segment;
    public byte [] opcode = new byte[3];
    public byte op_size;
    public byte addr_size;
    public byte disp_size;
    public byte imm_size;
    public byte modrm;
    public byte sib;
    public int disp;
    public int sib_index;
    public byte sib_scale;
    public int sib_base;

    public int op_count;

    public Operand [] op = new Operand[8];

    public UnionOpInfo(Pointer p) {
      super(p);
      read();
    }

    @Override
    public List getFieldOrder() {
      return Arrays.asList("prefix", "segment", "opcode", "op_size", "addr_size", "disp_size",
          "imm_size", "modrm", "sib", "disp", "sib_index", "sib_scale", "sib_base", "op_count", "op");
    }
  }

  public static class OpInfo extends Capstone.OpInfo {
    public byte [] prefix;
    public int segment;
    public byte [] opcode;
    public byte op_size;
    public byte addr_size;
    public byte disp_size;
    public byte imm_size;
    public byte modrm;
    public byte sib;
    public int disp;
    public int sib_index;
    public byte sib_scale;
    public int sib_base;

    public Operand[] op;

    public OpInfo(UnionOpInfo e) {
      prefix = e.prefix;
      segment = e.segment;
      opcode = e.opcode;
      op_size = e.op_size;
      addr_size = e.addr_size;
      disp_size = e.disp_size;
      imm_size = e.imm_size;
      modrm = e.modrm;
      sib = e.sib;
      disp = e.disp;
      sib_index = e.sib_index;
      sib_scale = e.sib_scale;
      sib_base = e.sib_base;
      if (e.op_count == 0) {
        op = null;
        return;
      }
      op = new Operand[e.op_count];
      for (int i=0; i<e.op_count; i++)
        op[i] = e.op[i];
    }
  }
  // all Intel reigsters
  public static final int X86_REG_INVALID = 0;
  public static final int X86_REG_AH = 1;
  public static final int X86_REG_AL = 2;
  public static final int X86_REG_AX = 3;
  public static final int X86_REG_BH = 4;
  public static final int X86_REG_BL = 5;
  public static final int X86_REG_BP = 6;
  public static final int X86_REG_BPL = 7;
  public static final int X86_REG_BX = 8;
  public static final int X86_REG_CH = 9;
  public static final int X86_REG_CL = 10;
  public static final int X86_REG_CS = 11;
  public static final int X86_REG_CX = 12;
  public static final int X86_REG_DH = 13;
  public static final int X86_REG_DI = 14;
  public static final int X86_REG_DIL = 15;
  public static final int X86_REG_DL = 16;
  public static final int X86_REG_DS = 17;
  public static final int X86_REG_DX = 18;
  public static final int X86_REG_EAX = 19;
  public static final int X86_REG_EBP = 20;
  public static final int X86_REG_EBX = 21;
  public static final int X86_REG_ECX = 22;
  public static final int X86_REG_EDI = 23;
  public static final int X86_REG_EDX = 24;
  public static final int X86_REG_FLAGS = 25;
  public static final int X86_REG_EIP = 26;
  public static final int X86_REG_EIZ = 27;
  public static final int X86_REG_ES = 28;
  public static final int X86_REG_ESI = 29;
  public static final int X86_REG_ESP = 30;
  public static final int X86_REG_FPSW = 31;
  public static final int X86_REG_FS = 32;
  public static final int X86_REG_GS = 33;
  public static final int X86_REG_IP = 34;
  public static final int X86_REG_RAX = 35;
  public static final int X86_REG_RBP = 36;
  public static final int X86_REG_RBX = 37;
  public static final int X86_REG_RCX = 38;
  public static final int X86_REG_RDI = 39;
  public static final int X86_REG_RDX = 40;
  public static final int X86_REG_RIP = 41;
  public static final int X86_REG_RIZ = 42;
  public static final int X86_REG_RSI = 43;
  public static final int X86_REG_RSP = 44;
  public static final int X86_REG_SI = 45;
  public static final int X86_REG_SIL = 46;
  public static final int X86_REG_SP = 47;
  public static final int X86_REG_SPL = 48;
  public static final int X86_REG_SS = 49;
  public static final int X86_REG_CR0 = 50;
  public static final int X86_REG_CR1 = 51;
  public static final int X86_REG_CR2 = 52;
  public static final int X86_REG_CR3 = 53;
  public static final int X86_REG_CR4 = 54;
  public static final int X86_REG_CR5 = 55;
  public static final int X86_REG_CR6 = 56;
  public static final int X86_REG_CR7 = 57;
  public static final int X86_REG_CR8 = 58;
  public static final int X86_REG_CR9 = 59;
  public static final int X86_REG_CR10 = 60;
  public static final int X86_REG_CR11 = 61;
  public static final int X86_REG_CR12 = 62;
  public static final int X86_REG_CR13 = 63;
  public static final int X86_REG_CR14 = 64;
  public static final int X86_REG_CR15 = 65;
  public static final int X86_REG_DR0 = 66;
  public static final int X86_REG_DR1 = 67;
  public static final int X86_REG_DR2 = 68;
  public static final int X86_REG_DR3 = 69;
  public static final int X86_REG_DR4 = 70;
  public static final int X86_REG_DR5 = 71;
  public static final int X86_REG_DR6 = 72;
  public static final int X86_REG_DR7 = 73;
  public static final int X86_REG_FP0 = 74;
  public static final int X86_REG_FP1 = 75;
  public static final int X86_REG_FP2 = 76;
  public static final int X86_REG_FP3 = 77;
  public static final int X86_REG_FP4 = 78;
  public static final int X86_REG_FP5 = 79;
  public static final int X86_REG_FP6 = 80;
  public static final int X86_REG_K0 = 81;
  public static final int X86_REG_K1 = 82;
  public static final int X86_REG_K2 = 83;
  public static final int X86_REG_K3 = 84;
  public static final int X86_REG_K4 = 85;
  public static final int X86_REG_K5 = 86;
  public static final int X86_REG_K6 = 87;
  public static final int X86_REG_K7 = 88;
  public static final int X86_REG_MM0 = 89;
  public static final int X86_REG_MM1 = 90;
  public static final int X86_REG_MM2 = 91;
  public static final int X86_REG_MM3 = 92;
  public static final int X86_REG_MM4 = 93;
  public static final int X86_REG_MM5 = 94;
  public static final int X86_REG_MM6 = 95;
  public static final int X86_REG_MM7 = 96;
  public static final int X86_REG_R8 = 97;
  public static final int X86_REG_R9 = 98;
  public static final int X86_REG_R10 = 99;
  public static final int X86_REG_R11 = 100;
  public static final int X86_REG_R12 = 101;
  public static final int X86_REG_R13 = 102;
  public static final int X86_REG_R14 = 103;
  public static final int X86_REG_R15 = 104;
  public static final int X86_REG_ST0 = 105;
  public static final int X86_REG_ST1 = 106;
  public static final int X86_REG_ST2 = 107;
  public static final int X86_REG_ST3 = 108;
  public static final int X86_REG_ST4 = 109;
  public static final int X86_REG_ST5 = 110;
  public static final int X86_REG_ST6 = 111;
  public static final int X86_REG_ST7 = 112;
  public static final int X86_REG_XMM0 = 113;
  public static final int X86_REG_XMM1 = 114;
  public static final int X86_REG_XMM2 = 115;
  public static final int X86_REG_XMM3 = 116;
  public static final int X86_REG_XMM4 = 117;
  public static final int X86_REG_XMM5 = 118;
  public static final int X86_REG_XMM6 = 119;
  public static final int X86_REG_XMM7 = 120;
  public static final int X86_REG_XMM8 = 121;
  public static final int X86_REG_XMM9 = 122;
  public static final int X86_REG_XMM10 = 123;
  public static final int X86_REG_XMM11 = 124;
  public static final int X86_REG_XMM12 = 125;
  public static final int X86_REG_XMM13 = 126;
  public static final int X86_REG_XMM14 = 127;
  public static final int X86_REG_XMM15 = 128;
  public static final int X86_REG_XMM16 = 129;
  public static final int X86_REG_XMM17 = 130;
  public static final int X86_REG_XMM18 = 131;
  public static final int X86_REG_XMM19 = 132;
  public static final int X86_REG_XMM20 = 133;
  public static final int X86_REG_XMM21 = 134;
  public static final int X86_REG_XMM22 = 135;
  public static final int X86_REG_XMM23 = 136;
  public static final int X86_REG_XMM24 = 137;
  public static final int X86_REG_XMM25 = 138;
  public static final int X86_REG_XMM26 = 139;
  public static final int X86_REG_XMM27 = 140;
  public static final int X86_REG_XMM28 = 141;
  public static final int X86_REG_XMM29 = 142;
  public static final int X86_REG_XMM30 = 143;
  public static final int X86_REG_XMM31 = 144;
  public static final int X86_REG_YMM0 = 145;
  public static final int X86_REG_YMM1 = 146;
  public static final int X86_REG_YMM2 = 147;
  public static final int X86_REG_YMM3 = 148;
  public static final int X86_REG_YMM4 = 149;
  public static final int X86_REG_YMM5 = 150;
  public static final int X86_REG_YMM6 = 151;
  public static final int X86_REG_YMM7 = 152;
  public static final int X86_REG_YMM8 = 153;
  public static final int X86_REG_YMM9 = 154;
  public static final int X86_REG_YMM10 = 155;
  public static final int X86_REG_YMM11 = 156;
  public static final int X86_REG_YMM12 = 157;
  public static final int X86_REG_YMM13 = 158;
  public static final int X86_REG_YMM14 = 159;
  public static final int X86_REG_YMM15 = 160;
  public static final int X86_REG_YMM16 = 161;
  public static final int X86_REG_YMM17 = 162;
  public static final int X86_REG_YMM18 = 163;
  public static final int X86_REG_YMM19 = 164;
  public static final int X86_REG_YMM20 = 165;
  public static final int X86_REG_YMM21 = 166;
  public static final int X86_REG_YMM22 = 167;
  public static final int X86_REG_YMM23 = 168;
  public static final int X86_REG_YMM24 = 169;
  public static final int X86_REG_YMM25 = 170;
  public static final int X86_REG_YMM26 = 171;
  public static final int X86_REG_YMM27 = 172;
  public static final int X86_REG_YMM28 = 173;
  public static final int X86_REG_YMM29 = 174;
  public static final int X86_REG_YMM30 = 175;
  public static final int X86_REG_YMM31 = 176;
  public static final int X86_REG_ZMM0 = 177;
  public static final int X86_REG_ZMM1 = 178;
  public static final int X86_REG_ZMM2 = 179;
  public static final int X86_REG_ZMM3 = 180;
  public static final int X86_REG_ZMM4 = 181;
  public static final int X86_REG_ZMM5 = 182;
  public static final int X86_REG_ZMM6 = 183;
  public static final int X86_REG_ZMM7 = 184;
  public static final int X86_REG_ZMM8 = 185;
  public static final int X86_REG_ZMM9 = 186;
  public static final int X86_REG_ZMM10 = 187;
  public static final int X86_REG_ZMM11 = 188;
  public static final int X86_REG_ZMM12 = 189;
  public static final int X86_REG_ZMM13 = 190;
  public static final int X86_REG_ZMM14 = 191;
  public static final int X86_REG_ZMM15 = 192;
  public static final int X86_REG_ZMM16 = 193;
  public static final int X86_REG_ZMM17 = 194;
  public static final int X86_REG_ZMM18 = 195;
  public static final int X86_REG_ZMM19 = 196;
  public static final int X86_REG_ZMM20 = 197;
  public static final int X86_REG_ZMM21 = 198;
  public static final int X86_REG_ZMM22 = 199;
  public static final int X86_REG_ZMM23 = 200;
  public static final int X86_REG_ZMM24 = 201;
  public static final int X86_REG_ZMM25 = 202;
  public static final int X86_REG_ZMM26 = 203;
  public static final int X86_REG_ZMM27 = 204;
  public static final int X86_REG_ZMM28 = 205;
  public static final int X86_REG_ZMM29 = 206;
  public static final int X86_REG_ZMM30 = 207;
  public static final int X86_REG_ZMM31 = 208;
  public static final int X86_REG_R8B = 209;
  public static final int X86_REG_R9B = 210;
  public static final int X86_REG_R10B = 211;
  public static final int X86_REG_R11B = 212;
  public static final int X86_REG_R12B = 213;
  public static final int X86_REG_R13B = 214;
  public static final int X86_REG_R14B = 215;
  public static final int X86_REG_R15B = 216;
  public static final int X86_REG_R8D = 217;
  public static final int X86_REG_R9D = 218;
  public static final int X86_REG_R10D = 219;
  public static final int X86_REG_R11D = 220;
  public static final int X86_REG_R12D = 221;
  public static final int X86_REG_R13D = 222;
  public static final int X86_REG_R14D = 223;
  public static final int X86_REG_R15D = 224;
  public static final int X86_REG_R8W = 225;
  public static final int X86_REG_R9W = 226;
  public static final int X86_REG_R10W = 227;
  public static final int X86_REG_R11W = 228;
  public static final int X86_REG_R12W = 229;
  public static final int X86_REG_R13W = 230;
  public static final int X86_REG_R14W = 231;
  public static final int X86_REG_R15W = 232;

  // all Intel instructions
  public static final int X86_INS_INVALID = 0;
  public static final int X86_INS_AAA = 1;
  public static final int X86_INS_AAD = 2;
  public static final int X86_INS_AAM = 3;
  public static final int X86_INS_AAS = 4;
  public static final int X86_INS_FABS = 5;
  public static final int X86_INS_ADC = 6;
  public static final int X86_INS_ADCX = 7;
  public static final int X86_INS_ADD = 8;
  public static final int X86_INS_ADDPD = 9;
  public static final int X86_INS_ADDPS = 10;
  public static final int X86_INS_ADDSD = 11;
  public static final int X86_INS_ADDSS = 12;
  public static final int X86_INS_ADDSUBPD = 13;
  public static final int X86_INS_ADDSUBPS = 14;
  public static final int X86_INS_FADD = 15;
  public static final int X86_INS_FIADD = 16;
  public static final int X86_INS_FADDP = 17;
  public static final int X86_INS_ADOX = 18;
  public static final int X86_INS_AESDECLAST = 19;
  public static final int X86_INS_AESDEC = 20;
  public static final int X86_INS_AESENCLAST = 21;
  public static final int X86_INS_AESENC = 22;
  public static final int X86_INS_AESIMC = 23;
  public static final int X86_INS_AESKEYGENASSIST = 24;
  public static final int X86_INS_AND = 25;
  public static final int X86_INS_ANDN = 26;
  public static final int X86_INS_ANDNPD = 27;
  public static final int X86_INS_ANDNPS = 28;
  public static final int X86_INS_ANDPD = 29;
  public static final int X86_INS_ANDPS = 30;
  public static final int X86_INS_ARPL = 31;
  public static final int X86_INS_BEXTR = 32;
  public static final int X86_INS_BLENDPD = 33;
  public static final int X86_INS_BLENDPS = 34;
  public static final int X86_INS_BLENDVPD = 35;
  public static final int X86_INS_BLENDVPS = 36;
  public static final int X86_INS_BLSI = 37;
  public static final int X86_INS_BLSMSK = 38;
  public static final int X86_INS_BLSR = 39;
  public static final int X86_INS_BOUND = 40;
  public static final int X86_INS_BSF = 41;
  public static final int X86_INS_BSR = 42;
  public static final int X86_INS_BSWAP = 43;
  public static final int X86_INS_BT = 44;
  public static final int X86_INS_BTC = 45;
  public static final int X86_INS_BTR = 46;
  public static final int X86_INS_BTS = 47;
  public static final int X86_INS_BZHI = 48;
  public static final int X86_INS_CALL = 49;
  public static final int X86_INS_CALLW = 50;
  public static final int X86_INS_CBW = 51;
  public static final int X86_INS_CDQ = 52;
  public static final int X86_INS_CDQE = 53;
  public static final int X86_INS_FCHS = 54;
  public static final int X86_INS_CLAC = 55;
  public static final int X86_INS_CLC = 56;
  public static final int X86_INS_CLD = 57;
  public static final int X86_INS_CLFLUSH = 58;
  public static final int X86_INS_CLGI = 59;
  public static final int X86_INS_CLI = 60;
  public static final int X86_INS_CLTS = 61;
  public static final int X86_INS_CMC = 62;
  public static final int X86_INS_CMOVA = 63;
  public static final int X86_INS_CMOVAE = 64;
  public static final int X86_INS_CMOVB = 65;
  public static final int X86_INS_CMOVBE = 66;
  public static final int X86_INS_FCMOVBE = 67;
  public static final int X86_INS_FCMOVB = 68;
  public static final int X86_INS_CMOVE = 69;
  public static final int X86_INS_FCMOVE = 70;
  public static final int X86_INS_CMOVG = 71;
  public static final int X86_INS_CMOVGE = 72;
  public static final int X86_INS_CMOVL = 73;
  public static final int X86_INS_CMOVLE = 74;
  public static final int X86_INS_FCMOVNBE = 75;
  public static final int X86_INS_FCMOVNB = 76;
  public static final int X86_INS_CMOVNE = 77;
  public static final int X86_INS_FCMOVNE = 78;
  public static final int X86_INS_CMOVNO = 79;
  public static final int X86_INS_CMOVNP = 80;
  public static final int X86_INS_FCMOVNU = 81;
  public static final int X86_INS_CMOVNS = 82;
  public static final int X86_INS_CMOVO = 83;
  public static final int X86_INS_CMOVP = 84;
  public static final int X86_INS_FCMOVU = 85;
  public static final int X86_INS_CMOVS = 86;
  public static final int X86_INS_CMP = 87;
  public static final int X86_INS_CMPPD = 88;
  public static final int X86_INS_CMPPS = 89;
  public static final int X86_INS_CMPSW = 90;
  public static final int X86_INS_CMPSD = 91;
  public static final int X86_INS_CMPSQ = 92;
  public static final int X86_INS_CMPSB = 93;
  public static final int X86_INS_CMPSS = 94;
  public static final int X86_INS_CMPXCHG16B = 95;
  public static final int X86_INS_CMPXCHG = 96;
  public static final int X86_INS_CMPXCHG8B = 97;
  public static final int X86_INS_COMISD = 98;
  public static final int X86_INS_COMISS = 99;
  public static final int X86_INS_FCOMP = 100;
  public static final int X86_INS_FCOMPI = 101;
  public static final int X86_INS_FCOMI = 102;
  public static final int X86_INS_FCOM = 103;
  public static final int X86_INS_FCOS = 104;
  public static final int X86_INS_CPUID = 105;
  public static final int X86_INS_CQO = 106;
  public static final int X86_INS_CRC32 = 107;
  public static final int X86_INS_CS = 108;
  public static final int X86_INS_CVTDQ2PD = 109;
  public static final int X86_INS_CVTDQ2PS = 110;
  public static final int X86_INS_CVTPD2DQ = 111;
  public static final int X86_INS_CVTPD2PS = 112;
  public static final int X86_INS_CVTPS2DQ = 113;
  public static final int X86_INS_CVTPS2PD = 114;
  public static final int X86_INS_CVTSD2SI = 115;
  public static final int X86_INS_CVTSD2SS = 116;
  public static final int X86_INS_CVTSI2SD = 117;
  public static final int X86_INS_CVTSI2SS = 118;
  public static final int X86_INS_CVTSS2SD = 119;
  public static final int X86_INS_CVTSS2SI = 120;
  public static final int X86_INS_CVTTPD2DQ = 121;
  public static final int X86_INS_CVTTPS2DQ = 122;
  public static final int X86_INS_CVTTSD2SI = 123;
  public static final int X86_INS_CVTTSS2SI = 124;
  public static final int X86_INS_CWD = 125;
  public static final int X86_INS_CWDE = 126;
  public static final int X86_INS_DAA = 127;
  public static final int X86_INS_DAS = 128;
  public static final int X86_INS_DATA16 = 129;
  public static final int X86_INS_DEC = 130;
  public static final int X86_INS_DIV = 131;
  public static final int X86_INS_DIVPD = 132;
  public static final int X86_INS_DIVPS = 133;
  public static final int X86_INS_FDIVR = 134;
  public static final int X86_INS_FIDIVR = 135;
  public static final int X86_INS_FDIVRP = 136;
  public static final int X86_INS_DIVSD = 137;
  public static final int X86_INS_DIVSS = 138;
  public static final int X86_INS_FDIV = 139;
  public static final int X86_INS_FIDIV = 140;
  public static final int X86_INS_FDIVP = 141;
  public static final int X86_INS_DPPD = 142;
  public static final int X86_INS_DPPS = 143;
  public static final int X86_INS_DS = 144;
  public static final int X86_INS_RET = 145;
  public static final int X86_INS_ENTER = 146;
  public static final int X86_INS_ES = 147;
  public static final int X86_INS_EXTRACTPS = 148;
  public static final int X86_INS_EXTRQ = 149;
  public static final int X86_INS_F2XM1 = 150;
  public static final int X86_INS_LCALL = 151;
  public static final int X86_INS_LJMP = 152;
  public static final int X86_INS_FBLD = 153;
  public static final int X86_INS_FBSTP = 154;
  public static final int X86_INS_FCOMPP = 155;
  public static final int X86_INS_FDECSTP = 156;
  public static final int X86_INS_FEMMS = 157;
  public static final int X86_INS_FFREE = 158;
  public static final int X86_INS_FICOM = 159;
  public static final int X86_INS_FICOMP = 160;
  public static final int X86_INS_FINCSTP = 161;
  public static final int X86_INS_FLDCW = 162;
  public static final int X86_INS_FLDENV = 163;
  public static final int X86_INS_FLDL2E = 164;
  public static final int X86_INS_FLDL2T = 165;
  public static final int X86_INS_FLDLG2 = 166;
  public static final int X86_INS_FLDLN2 = 167;
  public static final int X86_INS_FLDPI = 168;
  public static final int X86_INS_FNCLEX = 169;
  public static final int X86_INS_FNINIT = 170;
  public static final int X86_INS_FNOP = 171;
  public static final int X86_INS_FNSTCW = 172;
  public static final int X86_INS_FNSTSW = 173;
  public static final int X86_INS_FPATAN = 174;
  public static final int X86_INS_FPREM = 175;
  public static final int X86_INS_FPREM1 = 176;
  public static final int X86_INS_FPTAN = 177;
  public static final int X86_INS_FRNDINT = 178;
  public static final int X86_INS_FRSTOR = 179;
  public static final int X86_INS_FNSAVE = 180;
  public static final int X86_INS_FSCALE = 181;
  public static final int X86_INS_FSINCOS = 182;
  public static final int X86_INS_FNSTENV = 183;
  public static final int X86_INS_FS = 184;
  public static final int X86_INS_FXAM = 185;
  public static final int X86_INS_FXRSTOR = 186;
  public static final int X86_INS_FXRSTORQ = 187;
  public static final int X86_INS_FXSAVE = 188;
  public static final int X86_INS_FXSAVEQ = 189;
  public static final int X86_INS_FXTRACT = 190;
  public static final int X86_INS_FYL2X = 191;
  public static final int X86_INS_FYL2XP1 = 192;
  public static final int X86_INS_MOVAPD = 193;
  public static final int X86_INS_MOVAPS = 194;
  public static final int X86_INS_ORPD = 195;
  public static final int X86_INS_ORPS = 196;
  public static final int X86_INS_VMOVAPD = 197;
  public static final int X86_INS_VMOVAPS = 198;
  public static final int X86_INS_XORPD = 199;
  public static final int X86_INS_XORPS = 200;
  public static final int X86_INS_GS = 201;
  public static final int X86_INS_HADDPD = 202;
  public static final int X86_INS_HADDPS = 203;
  public static final int X86_INS_HLT = 204;
  public static final int X86_INS_HSUBPD = 205;
  public static final int X86_INS_HSUBPS = 206;
  public static final int X86_INS_IDIV = 207;
  public static final int X86_INS_FILD = 208;
  public static final int X86_INS_IMUL = 209;
  public static final int X86_INS_INS = 210;
  public static final int X86_INS_IN = 211;
  public static final int X86_INS_INC = 212;
  public static final int X86_INS_INSERTPS = 213;
  public static final int X86_INS_INSERTQ = 214;
  public static final int X86_INS_INT = 215;
  public static final int X86_INS_INT3 = 216;
  public static final int X86_INS_INTO = 217;
  public static final int X86_INS_INVD = 218;
  public static final int X86_INS_INVEPT = 219;
  public static final int X86_INS_INVLPG = 220;
  public static final int X86_INS_INVLPGA = 221;
  public static final int X86_INS_INVPCID = 222;
  public static final int X86_INS_INVVPID = 223;
  public static final int X86_INS_IRET = 224;
  public static final int X86_INS_IRETD = 225;
  public static final int X86_INS_IRETQ = 226;
  public static final int X86_INS_FISTTP = 227;
  public static final int X86_INS_FIST = 228;
  public static final int X86_INS_FISTP = 229;
  public static final int X86_INS_UCOMISD = 230;
  public static final int X86_INS_UCOMISS = 231;
  public static final int X86_INS_VCMPSD = 232;
  public static final int X86_INS_VCMPSS = 233;
  public static final int X86_INS_VCOMISD = 234;
  public static final int X86_INS_VCOMISS = 235;
  public static final int X86_INS_VCVTSD2SS = 236;
  public static final int X86_INS_VCVTSI2SD = 237;
  public static final int X86_INS_VCVTSI2SS = 238;
  public static final int X86_INS_VCVTSS2SD = 239;
  public static final int X86_INS_VCVTTSD2SI = 240;
  public static final int X86_INS_VCVTTSS2SI = 241;
  public static final int X86_INS_VUCOMISD = 242;
  public static final int X86_INS_VUCOMISS = 243;
  public static final int X86_INS_JAE = 244;
  public static final int X86_INS_JA = 245;
  public static final int X86_INS_JBE = 246;
  public static final int X86_INS_JB = 247;
  public static final int X86_INS_JCXZ = 248;
  public static final int X86_INS_JECXZ = 249;
  public static final int X86_INS_JE = 250;
  public static final int X86_INS_JGE = 251;
  public static final int X86_INS_JG = 252;
  public static final int X86_INS_JLE = 253;
  public static final int X86_INS_JL = 254;
  public static final int X86_INS_JMP = 255;
  public static final int X86_INS_JMPQ = 256;
  public static final int X86_INS_JNE = 257;
  public static final int X86_INS_JNO = 258;
  public static final int X86_INS_JNP = 259;
  public static final int X86_INS_JNS = 260;
  public static final int X86_INS_JO = 261;
  public static final int X86_INS_JP = 262;
  public static final int X86_INS_JRCXZ = 263;
  public static final int X86_INS_JS = 264;
  public static final int X86_INS_KADDW = 265;
  public static final int X86_INS_KANDNW = 266;
  public static final int X86_INS_KANDW = 267;
  public static final int X86_INS_KMOVW = 268;
  public static final int X86_INS_KNOTW = 269;
  public static final int X86_INS_KORTESTW = 270;
  public static final int X86_INS_KORW = 271;
  public static final int X86_INS_KSHIFTLW = 272;
  public static final int X86_INS_KSHIFTRW = 273;
  public static final int X86_INS_KTESTW = 274;
  public static final int X86_INS_KUNPCKBW = 275;
  public static final int X86_INS_KXNORW = 276;
  public static final int X86_INS_KXORW = 277;
  public static final int X86_INS_LAHF = 278;
  public static final int X86_INS_LAR = 279;
  public static final int X86_INS_LDDQU = 280;
  public static final int X86_INS_LDMXCSR = 281;
  public static final int X86_INS_LDS = 282;
  public static final int X86_INS_FLDZ = 283;
  public static final int X86_INS_FLD1 = 284;
  public static final int X86_INS_FLD = 285;
  public static final int X86_INS_LEA = 286;
  public static final int X86_INS_LEAVE = 287;
  public static final int X86_INS_LES = 288;
  public static final int X86_INS_LFENCE = 289;
  public static final int X86_INS_LFS = 290;
  public static final int X86_INS_LGDT = 291;
  public static final int X86_INS_LGS = 292;
  public static final int X86_INS_LIDT = 293;
  public static final int X86_INS_LLDT = 294;
  public static final int X86_INS_LMSW = 295;
  public static final int X86_INS_OR = 296;
  public static final int X86_INS_LOCK = 297;
  public static final int X86_INS_SUB = 298;
  public static final int X86_INS_XOR = 299;
  public static final int X86_INS_LODSB = 300;
  public static final int X86_INS_LODSD = 301;
  public static final int X86_INS_LODSQ = 302;
  public static final int X86_INS_LODSW = 303;
  public static final int X86_INS_LOOP = 304;
  public static final int X86_INS_LOOPE = 305;
  public static final int X86_INS_LOOPNE = 306;
  public static final int X86_INS_RETF = 307;
  public static final int X86_INS_LSL = 308;
  public static final int X86_INS_LSS = 309;
  public static final int X86_INS_LTR = 310;
  public static final int X86_INS_XADD = 311;
  public static final int X86_INS_LZCNT = 312;
  public static final int X86_INS_MASKMOVDQU = 313;
  public static final int X86_INS_MAXPD = 314;
  public static final int X86_INS_MAXPS = 315;
  public static final int X86_INS_MAXSD = 316;
  public static final int X86_INS_MAXSS = 317;
  public static final int X86_INS_MFENCE = 318;
  public static final int X86_INS_MINPD = 319;
  public static final int X86_INS_MINPS = 320;
  public static final int X86_INS_MINSD = 321;
  public static final int X86_INS_MINSS = 322;
  public static final int X86_INS_CVTPD2PI = 323;
  public static final int X86_INS_CVTPI2PD = 324;
  public static final int X86_INS_CVTPI2PS = 325;
  public static final int X86_INS_CVTPS2PI = 326;
  public static final int X86_INS_CVTTPD2PI = 327;
  public static final int X86_INS_CVTTPS2PI = 328;
  public static final int X86_INS_EMMS = 329;
  public static final int X86_INS_MASKMOVQ = 330;
  public static final int X86_INS_MOVD = 331;
  public static final int X86_INS_MOVDQ2Q = 332;
  public static final int X86_INS_MOVNTQ = 333;
  public static final int X86_INS_MOVQ2DQ = 334;
  public static final int X86_INS_MOVQ = 335;
  public static final int X86_INS_PABSB = 336;
  public static final int X86_INS_PABSD = 337;
  public static final int X86_INS_PABSW = 338;
  public static final int X86_INS_PACKSSDW = 339;
  public static final int X86_INS_PACKSSWB = 340;
  public static final int X86_INS_PACKUSWB = 341;
  public static final int X86_INS_PADDB = 342;
  public static final int X86_INS_PADDD = 343;
  public static final int X86_INS_PADDQ = 344;
  public static final int X86_INS_PADDSB = 345;
  public static final int X86_INS_PADDSW = 346;
  public static final int X86_INS_PADDUSB = 347;
  public static final int X86_INS_PADDUSW = 348;
  public static final int X86_INS_PADDW = 349;
  public static final int X86_INS_PALIGNR = 350;
  public static final int X86_INS_PANDN = 351;
  public static final int X86_INS_PAND = 352;
  public static final int X86_INS_PAVGB = 353;
  public static final int X86_INS_PAVGW = 354;
  public static final int X86_INS_PCMPEQB = 355;
  public static final int X86_INS_PCMPEQD = 356;
  public static final int X86_INS_PCMPEQW = 357;
  public static final int X86_INS_PCMPGTB = 358;
  public static final int X86_INS_PCMPGTD = 359;
  public static final int X86_INS_PCMPGTW = 360;
  public static final int X86_INS_PEXTRW = 361;
  public static final int X86_INS_PHADDSW = 362;
  public static final int X86_INS_PHADDW = 363;
  public static final int X86_INS_PHADDD = 364;
  public static final int X86_INS_PHSUBD = 365;
  public static final int X86_INS_PHSUBSW = 366;
  public static final int X86_INS_PHSUBW = 367;
  public static final int X86_INS_PINSRW = 368;
  public static final int X86_INS_PMADDUBSW = 369;
  public static final int X86_INS_PMADDWD = 370;
  public static final int X86_INS_PMAXSW = 371;
  public static final int X86_INS_PMAXUB = 372;
  public static final int X86_INS_PMINSW = 373;
  public static final int X86_INS_PMINUB = 374;
  public static final int X86_INS_PMOVMSKB = 375;
  public static final int X86_INS_PMULHRSW = 376;
  public static final int X86_INS_PMULHUW = 377;
  public static final int X86_INS_PMULHW = 378;
  public static final int X86_INS_PMULLW = 379;
  public static final int X86_INS_PMULUDQ = 380;
  public static final int X86_INS_POR = 381;
  public static final int X86_INS_PSADBW = 382;
  public static final int X86_INS_PSHUFB = 383;
  public static final int X86_INS_PSHUFW = 384;
  public static final int X86_INS_PSIGNB = 385;
  public static final int X86_INS_PSIGND = 386;
  public static final int X86_INS_PSIGNW = 387;
  public static final int X86_INS_PSLLD = 388;
  public static final int X86_INS_PSLLQ = 389;
  public static final int X86_INS_PSLLW = 390;
  public static final int X86_INS_PSRAD = 391;
  public static final int X86_INS_PSRAW = 392;
  public static final int X86_INS_PSRLD = 393;
  public static final int X86_INS_PSRLQ = 394;
  public static final int X86_INS_PSRLW = 395;
  public static final int X86_INS_PSUBB = 396;
  public static final int X86_INS_PSUBD = 397;
  public static final int X86_INS_PSUBQ = 398;
  public static final int X86_INS_PSUBSB = 399;
  public static final int X86_INS_PSUBSW = 400;
  public static final int X86_INS_PSUBUSB = 401;
  public static final int X86_INS_PSUBUSW = 402;
  public static final int X86_INS_PSUBW = 403;
  public static final int X86_INS_PUNPCKHBW = 404;
  public static final int X86_INS_PUNPCKHDQ = 405;
  public static final int X86_INS_PUNPCKHWD = 406;
  public static final int X86_INS_PUNPCKLBW = 407;
  public static final int X86_INS_PUNPCKLDQ = 408;
  public static final int X86_INS_PUNPCKLWD = 409;
  public static final int X86_INS_PXOR = 410;
  public static final int X86_INS_MONITOR = 411;
  public static final int X86_INS_MONTMUL = 412;
  public static final int X86_INS_MOV = 413;
  public static final int X86_INS_MOVABS = 414;
  public static final int X86_INS_MOVBE = 415;
  public static final int X86_INS_MOVDDUP = 416;
  public static final int X86_INS_MOVDQA = 417;
  public static final int X86_INS_MOVDQU = 418;
  public static final int X86_INS_MOVHLPS = 419;
  public static final int X86_INS_MOVHPD = 420;
  public static final int X86_INS_MOVHPS = 421;
  public static final int X86_INS_MOVLHPS = 422;
  public static final int X86_INS_MOVLPD = 423;
  public static final int X86_INS_MOVLPS = 424;
  public static final int X86_INS_MOVMSKPD = 425;
  public static final int X86_INS_MOVMSKPS = 426;
  public static final int X86_INS_MOVNTDQA = 427;
  public static final int X86_INS_MOVNTDQ = 428;
  public static final int X86_INS_MOVNTI = 429;
  public static final int X86_INS_MOVNTPD = 430;
  public static final int X86_INS_MOVNTPS = 431;
  public static final int X86_INS_MOVNTSD = 432;
  public static final int X86_INS_MOVNTSS = 433;
  public static final int X86_INS_MOVSB = 434;
  public static final int X86_INS_MOVSD = 435;
  public static final int X86_INS_MOVSHDUP = 436;
  public static final int X86_INS_MOVSLDUP = 437;
  public static final int X86_INS_MOVSQ = 438;
  public static final int X86_INS_MOVSS = 439;
  public static final int X86_INS_MOVSW = 440;
  public static final int X86_INS_MOVSX = 441;
  public static final int X86_INS_MOVSXD = 442;
  public static final int X86_INS_MOVUPD = 443;
  public static final int X86_INS_MOVUPS = 444;
  public static final int X86_INS_MOVZX = 445;
  public static final int X86_INS_MPSADBW = 446;
  public static final int X86_INS_MUL = 447;
  public static final int X86_INS_MULPD = 448;
  public static final int X86_INS_MULPS = 449;
  public static final int X86_INS_MULSD = 450;
  public static final int X86_INS_MULSS = 451;
  public static final int X86_INS_MULX = 452;
  public static final int X86_INS_FMUL = 453;
  public static final int X86_INS_FIMUL = 454;
  public static final int X86_INS_FMULP = 455;
  public static final int X86_INS_MWAIT = 456;
  public static final int X86_INS_NEG = 457;
  public static final int X86_INS_NOP = 458;
  public static final int X86_INS_NOT = 459;
  public static final int X86_INS_OUT = 460;
  public static final int X86_INS_OUTSB = 461;
  public static final int X86_INS_OUTSD = 462;
  public static final int X86_INS_OUTSW = 463;
  public static final int X86_INS_PACKUSDW = 464;
  public static final int X86_INS_PAUSE = 465;
  public static final int X86_INS_PAVGUSB = 466;
  public static final int X86_INS_PBLENDVB = 467;
  public static final int X86_INS_PBLENDW = 468;
  public static final int X86_INS_PCLMULQDQ = 469;
  public static final int X86_INS_PCMPEQQ = 470;
  public static final int X86_INS_PCMPESTRI = 471;
  public static final int X86_INS_PCMPESTRM = 472;
  public static final int X86_INS_PCMPGTQ = 473;
  public static final int X86_INS_PCMPISTRI = 474;
  public static final int X86_INS_PCMPISTRM = 475;
  public static final int X86_INS_PDEP = 476;
  public static final int X86_INS_PEXT = 477;
  public static final int X86_INS_PEXTRB = 478;
  public static final int X86_INS_PEXTRD = 479;
  public static final int X86_INS_PEXTRQ = 480;
  public static final int X86_INS_PF2ID = 481;
  public static final int X86_INS_PF2IW = 482;
  public static final int X86_INS_PFACC = 483;
  public static final int X86_INS_PFADD = 484;
  public static final int X86_INS_PFCMPEQ = 485;
  public static final int X86_INS_PFCMPGE = 486;
  public static final int X86_INS_PFCMPGT = 487;
  public static final int X86_INS_PFMAX = 488;
  public static final int X86_INS_PFMIN = 489;
  public static final int X86_INS_PFMUL = 490;
  public static final int X86_INS_PFNACC = 491;
  public static final int X86_INS_PFPNACC = 492;
  public static final int X86_INS_PFRCPIT1 = 493;
  public static final int X86_INS_PFRCPIT2 = 494;
  public static final int X86_INS_PFRCP = 495;
  public static final int X86_INS_PFRSQIT1 = 496;
  public static final int X86_INS_PFRSQRT = 497;
  public static final int X86_INS_PFSUBR = 498;
  public static final int X86_INS_PFSUB = 499;
  public static final int X86_INS_PHMINPOSUW = 500;
  public static final int X86_INS_PI2FD = 501;
  public static final int X86_INS_PI2FW = 502;
  public static final int X86_INS_PINSRB = 503;
  public static final int X86_INS_PINSRD = 504;
  public static final int X86_INS_PINSRQ = 505;
  public static final int X86_INS_PMAXSB = 506;
  public static final int X86_INS_PMAXSD = 507;
  public static final int X86_INS_PMAXUD = 508;
  public static final int X86_INS_PMAXUW = 509;
  public static final int X86_INS_PMINSB = 510;
  public static final int X86_INS_PMINSD = 511;
  public static final int X86_INS_PMINUD = 512;
  public static final int X86_INS_PMINUW = 513;
  public static final int X86_INS_PMOVSXBD = 514;
  public static final int X86_INS_PMOVSXBQ = 515;
  public static final int X86_INS_PMOVSXBW = 516;
  public static final int X86_INS_PMOVSXDQ = 517;
  public static final int X86_INS_PMOVSXWD = 518;
  public static final int X86_INS_PMOVSXWQ = 519;
  public static final int X86_INS_PMOVZXBD = 520;
  public static final int X86_INS_PMOVZXBQ = 521;
  public static final int X86_INS_PMOVZXBW = 522;
  public static final int X86_INS_PMOVZXDQ = 523;
  public static final int X86_INS_PMOVZXWD = 524;
  public static final int X86_INS_PMOVZXWQ = 525;
  public static final int X86_INS_PMULDQ = 526;
  public static final int X86_INS_PMULHRW = 527;
  public static final int X86_INS_PMULLD = 528;
  public static final int X86_INS_POP = 529;
  public static final int X86_INS_POPA = 530;
  public static final int X86_INS_POPCNT = 531;
  public static final int X86_INS_POPF = 532;
  public static final int X86_INS_POPFD = 533;
  public static final int X86_INS_POPFQ = 534;
  public static final int X86_INS_PREFETCH = 535;
  public static final int X86_INS_PREFETCHNTA = 536;
  public static final int X86_INS_PREFETCHT0 = 537;
  public static final int X86_INS_PREFETCHT1 = 538;
  public static final int X86_INS_PREFETCHT2 = 539;
  public static final int X86_INS_PREFETCHW = 540;
  public static final int X86_INS_PSHUFD = 541;
  public static final int X86_INS_PSHUFHW = 542;
  public static final int X86_INS_PSHUFLW = 543;
  public static final int X86_INS_PSLLDQ = 544;
  public static final int X86_INS_PSRLDQ = 545;
  public static final int X86_INS_PSWAPD = 546;
  public static final int X86_INS_PTEST = 547;
  public static final int X86_INS_PUNPCKHQDQ = 548;
  public static final int X86_INS_PUNPCKLQDQ = 549;
  public static final int X86_INS_PUSH = 550;
  public static final int X86_INS_PUSHA = 551;
  public static final int X86_INS_PUSHF = 552;
  public static final int X86_INS_PUSHFD = 553;
  public static final int X86_INS_PUSHFQ = 554;
  public static final int X86_INS_RCL = 555;
  public static final int X86_INS_RCPPS = 556;
  public static final int X86_INS_RCPSS = 557;
  public static final int X86_INS_RCR = 558;
  public static final int X86_INS_RDFSBASE = 559;
  public static final int X86_INS_RDGSBASE = 560;
  public static final int X86_INS_RDMSR = 561;
  public static final int X86_INS_RDPMC = 562;
  public static final int X86_INS_RDRAND = 563;
  public static final int X86_INS_RDSEED = 564;
  public static final int X86_INS_RDTSC = 565;
  public static final int X86_INS_RDTSCP = 566;
  public static final int X86_INS_REPNE = 567;
  public static final int X86_INS_REP = 568;
  public static final int X86_INS_REX64 = 569;
  public static final int X86_INS_ROL = 570;
  public static final int X86_INS_ROR = 571;
  public static final int X86_INS_RORX = 572;
  public static final int X86_INS_ROUNDPD = 573;
  public static final int X86_INS_ROUNDPS = 574;
  public static final int X86_INS_ROUNDSD = 575;
  public static final int X86_INS_ROUNDSS = 576;
  public static final int X86_INS_RSM = 577;
  public static final int X86_INS_RSQRTPS = 578;
  public static final int X86_INS_RSQRTSS = 579;
  public static final int X86_INS_SAHF = 580;
  public static final int X86_INS_SAR = 581;
  public static final int X86_INS_SARX = 582;
  public static final int X86_INS_SBB = 583;
  public static final int X86_INS_SCASW = 584;
  public static final int X86_INS_SCASD = 585;
  public static final int X86_INS_SCASQ = 586;
  public static final int X86_INS_SCASB = 587;
  public static final int X86_INS_SETAE = 588;
  public static final int X86_INS_SETA = 589;
  public static final int X86_INS_SETBE = 590;
  public static final int X86_INS_SETB = 591;
  public static final int X86_INS_SETE = 592;
  public static final int X86_INS_SETGE = 593;
  public static final int X86_INS_SETG = 594;
  public static final int X86_INS_SETLE = 595;
  public static final int X86_INS_SETL = 596;
  public static final int X86_INS_SETNE = 597;
  public static final int X86_INS_SETNO = 598;
  public static final int X86_INS_SETNP = 599;
  public static final int X86_INS_SETNS = 600;
  public static final int X86_INS_SETO = 601;
  public static final int X86_INS_SETP = 602;
  public static final int X86_INS_SETS = 603;
  public static final int X86_INS_SFENCE = 604;
  public static final int X86_INS_SGDT = 605;
  public static final int X86_INS_SHA1MSG1 = 606;
  public static final int X86_INS_SHA1MSG2 = 607;
  public static final int X86_INS_SHA1NEXTE = 608;
  public static final int X86_INS_SHA1RNDS4 = 609;
  public static final int X86_INS_SHA256MSG1 = 610;
  public static final int X86_INS_SHA256MSG2 = 611;
  public static final int X86_INS_SHA256RNDS2 = 612;
  public static final int X86_INS_SHL = 613;
  public static final int X86_INS_SHLD = 614;
  public static final int X86_INS_SHLX = 615;
  public static final int X86_INS_SHR = 616;
  public static final int X86_INS_SHRD = 617;
  public static final int X86_INS_SHRX = 618;
  public static final int X86_INS_SHUFPD = 619;
  public static final int X86_INS_SHUFPS = 620;
  public static final int X86_INS_SIDT = 621;
  public static final int X86_INS_FSIN = 622;
  public static final int X86_INS_SKINIT = 623;
  public static final int X86_INS_SLDT = 624;
  public static final int X86_INS_SMSW = 625;
  public static final int X86_INS_SQRTPD = 626;
  public static final int X86_INS_SQRTPS = 627;
  public static final int X86_INS_SQRTSD = 628;
  public static final int X86_INS_SQRTSS = 629;
  public static final int X86_INS_FSQRT = 630;
  public static final int X86_INS_SS = 631;
  public static final int X86_INS_STAC = 632;
  public static final int X86_INS_STC = 633;
  public static final int X86_INS_STD = 634;
  public static final int X86_INS_STGI = 635;
  public static final int X86_INS_STI = 636;
  public static final int X86_INS_STMXCSR = 637;
  public static final int X86_INS_STOSB = 638;
  public static final int X86_INS_STOSD = 639;
  public static final int X86_INS_STOSQ = 640;
  public static final int X86_INS_STOSW = 641;
  public static final int X86_INS_STR = 642;
  public static final int X86_INS_FST = 643;
  public static final int X86_INS_FSTP = 644;
  public static final int X86_INS_SUBPD = 645;
  public static final int X86_INS_SUBPS = 646;
  public static final int X86_INS_FSUBR = 647;
  public static final int X86_INS_FISUBR = 648;
  public static final int X86_INS_FSUBRP = 649;
  public static final int X86_INS_SUBSD = 650;
  public static final int X86_INS_SUBSS = 651;
  public static final int X86_INS_FSUB = 652;
  public static final int X86_INS_FISUB = 653;
  public static final int X86_INS_FSUBP = 654;
  public static final int X86_INS_SWAPGS = 655;
  public static final int X86_INS_SYSCALL = 656;
  public static final int X86_INS_SYSENTER = 657;
  public static final int X86_INS_SYSEXIT = 658;
  public static final int X86_INS_SYSRET = 659;
  public static final int X86_INS_TEST = 660;
  public static final int X86_INS_UD2 = 661;
  public static final int X86_INS_FTST = 662;
  public static final int X86_INS_TZCNT = 663;
  public static final int X86_INS_FUCOMPI = 664;
  public static final int X86_INS_FUCOMI = 665;
  public static final int X86_INS_FUCOMPP = 666;
  public static final int X86_INS_FUCOMP = 667;
  public static final int X86_INS_FUCOM = 668;
  public static final int X86_INS_UD2B = 669;
  public static final int X86_INS_UNPCKHPD = 670;
  public static final int X86_INS_UNPCKHPS = 671;
  public static final int X86_INS_UNPCKLPD = 672;
  public static final int X86_INS_UNPCKLPS = 673;
  public static final int X86_INS_VADDPD = 674;
  public static final int X86_INS_VADDPS = 675;
  public static final int X86_INS_VADDSD = 676;
  public static final int X86_INS_VADDSS = 677;
  public static final int X86_INS_VADDSUBPD = 678;
  public static final int X86_INS_VADDSUBPS = 679;
  public static final int X86_INS_VAESDECLAST = 680;
  public static final int X86_INS_VAESDEC = 681;
  public static final int X86_INS_VAESENCLAST = 682;
  public static final int X86_INS_VAESENC = 683;
  public static final int X86_INS_VAESIMC = 684;
  public static final int X86_INS_VAESKEYGENASSIST = 685;
  public static final int X86_INS_VALIGND = 686;
  public static final int X86_INS_VALIGNQ = 687;
  public static final int X86_INS_VANDNPD = 688;
  public static final int X86_INS_VANDNPS = 689;
  public static final int X86_INS_VANDPD = 690;
  public static final int X86_INS_VANDPS = 691;
  public static final int X86_INS_VBLENDMPD = 692;
  public static final int X86_INS_VBLENDMPS = 693;
  public static final int X86_INS_VBLENDPD = 694;
  public static final int X86_INS_VBLENDPS = 695;
  public static final int X86_INS_VBLENDVPD = 696;
  public static final int X86_INS_VBLENDVPS = 697;
  public static final int X86_INS_VBROADCASTF128 = 698;
  public static final int X86_INS_VBROADCASTI128 = 699;
  public static final int X86_INS_VBROADCASTSD = 700;
  public static final int X86_INS_VBROADCASTSS = 701;
  public static final int X86_INS_VCMPPD = 702;
  public static final int X86_INS_VVCMPPD = 703;
  public static final int X86_INS_VCMPPS = 704;
  public static final int X86_INS_VVCMPPS = 705;
  public static final int X86_INS_VCVTDQ2PD = 706;
  public static final int X86_INS_VCVTDQ2PS = 707;
  public static final int X86_INS_VCVTPD2DQX = 708;
  public static final int X86_INS_VCVTPD2DQ = 709;
  public static final int X86_INS_VCVTPD2PSX = 710;
  public static final int X86_INS_VCVTPD2PS = 711;
  public static final int X86_INS_VCVTPH2PS = 712;
  public static final int X86_INS_VCVTPS2DQ = 713;
  public static final int X86_INS_VCVTPS2PD = 714;
  public static final int X86_INS_VCVTPS2PH = 715;
  public static final int X86_INS_VCVTSD2SI = 716;
  public static final int X86_INS_VCVTSS2SI = 717;
  public static final int X86_INS_VCVTTPD2DQX = 718;
  public static final int X86_INS_VCVTTPD2DQ = 719;
  public static final int X86_INS_VCVTTPD2UDQ = 720;
  public static final int X86_INS_VCVTTPS2DQ = 721;
  public static final int X86_INS_VCVTTPS2UDQ = 722;
  public static final int X86_INS_VCVTUDQ2PD = 723;
  public static final int X86_INS_VCVTUDQ2PS = 724;
  public static final int X86_INS_VDIVPD = 725;
  public static final int X86_INS_VDIVPS = 726;
  public static final int X86_INS_VDIVSD = 727;
  public static final int X86_INS_VDIVSS = 728;
  public static final int X86_INS_VDPPD = 729;
  public static final int X86_INS_VDPPS = 730;
  public static final int X86_INS_VERR = 731;
  public static final int X86_INS_VERW = 732;
  public static final int X86_INS_VEXTRACTF128 = 733;
  public static final int X86_INS_VEXTRACTF32X4 = 734;
  public static final int X86_INS_VEXTRACTF64X4 = 735;
  public static final int X86_INS_VEXTRACTI128 = 736;
  public static final int X86_INS_VEXTRACTI32X4 = 737;
  public static final int X86_INS_VEXTRACTI64X4 = 738;
  public static final int X86_INS_VEXTRACTPS = 739;
  public static final int X86_INS_VFMADD132PD = 740;
  public static final int X86_INS_VFMADD132PS = 741;
  public static final int X86_INS_VFMADD213PD = 742;
  public static final int X86_INS_VFMADD213PS = 743;
  public static final int X86_INS_VFMADDPD = 744;
  public static final int X86_INS_VFMADD231PD = 745;
  public static final int X86_INS_VFMADDPS = 746;
  public static final int X86_INS_VFMADD231PS = 747;
  public static final int X86_INS_VFMADDSD = 748;
  public static final int X86_INS_VFMADD213SD = 749;
  public static final int X86_INS_VFMADD132SD = 750;
  public static final int X86_INS_VFMADD231SD = 751;
  public static final int X86_INS_VFMADDSS = 752;
  public static final int X86_INS_VFMADD213SS = 753;
  public static final int X86_INS_VFMADD132SS = 754;
  public static final int X86_INS_VFMADD231SS = 755;
  public static final int X86_INS_VFMADDSUB132PD = 756;
  public static final int X86_INS_VFMADDSUB132PS = 757;
  public static final int X86_INS_VFMADDSUB213PD = 758;
  public static final int X86_INS_VFMADDSUB213PS = 759;
  public static final int X86_INS_VFMADDSUBPD = 760;
  public static final int X86_INS_VFMADDSUB231PD = 761;
  public static final int X86_INS_VFMADDSUBPS = 762;
  public static final int X86_INS_VFMADDSUB231PS = 763;
  public static final int X86_INS_VFMSUB132PD = 764;
  public static final int X86_INS_VFMSUB132PS = 765;
  public static final int X86_INS_VFMSUB213PD = 766;
  public static final int X86_INS_VFMSUB213PS = 767;
  public static final int X86_INS_VFMSUBADD132PD = 768;
  public static final int X86_INS_VFMSUBADD132PS = 769;
  public static final int X86_INS_VFMSUBADD213PD = 770;
  public static final int X86_INS_VFMSUBADD213PS = 771;
  public static final int X86_INS_VFMSUBADDPD = 772;
  public static final int X86_INS_VFMSUBADD231PD = 773;
  public static final int X86_INS_VFMSUBADDPS = 774;
  public static final int X86_INS_VFMSUBADD231PS = 775;
  public static final int X86_INS_VFMSUBPD = 776;
  public static final int X86_INS_VFMSUB231PD = 777;
  public static final int X86_INS_VFMSUBPS = 778;
  public static final int X86_INS_VFMSUB231PS = 779;
  public static final int X86_INS_VFMSUBSD = 780;
  public static final int X86_INS_VFMSUB213SD = 781;
  public static final int X86_INS_VFMSUB132SD = 782;
  public static final int X86_INS_VFMSUB231SD = 783;
  public static final int X86_INS_VFMSUBSS = 784;
  public static final int X86_INS_VFMSUB213SS = 785;
  public static final int X86_INS_VFMSUB132SS = 786;
  public static final int X86_INS_VFMSUB231SS = 787;
  public static final int X86_INS_VFNMADD132PD = 788;
  public static final int X86_INS_VFNMADD132PS = 789;
  public static final int X86_INS_VFNMADD213PD = 790;
  public static final int X86_INS_VFNMADD213PS = 791;
  public static final int X86_INS_VFNMADDPD = 792;
  public static final int X86_INS_VFNMADD231PD = 793;
  public static final int X86_INS_VFNMADDPS = 794;
  public static final int X86_INS_VFNMADD231PS = 795;
  public static final int X86_INS_VFNMADDSD = 796;
  public static final int X86_INS_VFNMADD213SD = 797;
  public static final int X86_INS_VFNMADD132SD = 798;
  public static final int X86_INS_VFNMADD231SD = 799;
  public static final int X86_INS_VFNMADDSS = 800;
  public static final int X86_INS_VFNMADD213SS = 801;
  public static final int X86_INS_VFNMADD132SS = 802;
  public static final int X86_INS_VFNMADD231SS = 803;
  public static final int X86_INS_VFNMSUB132PD = 804;
  public static final int X86_INS_VFNMSUB132PS = 805;
  public static final int X86_INS_VFNMSUB213PD = 806;
  public static final int X86_INS_VFNMSUB213PS = 807;
  public static final int X86_INS_VFNMSUBPD = 808;
  public static final int X86_INS_VFNMSUB231PD = 809;
  public static final int X86_INS_VFNMSUBPS = 810;
  public static final int X86_INS_VFNMSUB231PS = 811;
  public static final int X86_INS_VFNMSUBSD = 812;
  public static final int X86_INS_VFNMSUB213SD = 813;
  public static final int X86_INS_VFNMSUB132SD = 814;
  public static final int X86_INS_VFNMSUB231SD = 815;
  public static final int X86_INS_VFNMSUBSS = 816;
  public static final int X86_INS_VFNMSUB213SS = 817;
  public static final int X86_INS_VFNMSUB132SS = 818;
  public static final int X86_INS_VFNMSUB231SS = 819;
  public static final int X86_INS_VFRCZPD = 820;
  public static final int X86_INS_VFRCZPS = 821;
  public static final int X86_INS_VFRCZSD = 822;
  public static final int X86_INS_VFRCZSS = 823;
  public static final int X86_INS_VORPD = 824;
  public static final int X86_INS_VORPS = 825;
  public static final int X86_INS_VXORPD = 826;
  public static final int X86_INS_VXORPS = 827;
  public static final int X86_INS_VGATHERDPD = 828;
  public static final int X86_INS_VGATHERDPS = 829;
  public static final int X86_INS_VGATHERQPD = 830;
  public static final int X86_INS_VGATHERQPS = 831;
  public static final int X86_INS_VHADDPD = 832;
  public static final int X86_INS_VHADDPS = 833;
  public static final int X86_INS_VHSUBPD = 834;
  public static final int X86_INS_VHSUBPS = 835;
  public static final int X86_INS_VINSERTF128 = 836;
  public static final int X86_INS_VINSERTF32X4 = 837;
  public static final int X86_INS_VINSERTF64X4 = 838;
  public static final int X86_INS_VINSERTI128 = 839;
  public static final int X86_INS_VINSERTI32X4 = 840;
  public static final int X86_INS_VINSERTI64X4 = 841;
  public static final int X86_INS_VINSERTPS = 842;
  public static final int X86_INS_VLDDQU = 843;
  public static final int X86_INS_VLDMXCSR = 844;
  public static final int X86_INS_VMASKMOVDQU = 845;
  public static final int X86_INS_VMASKMOVPD = 846;
  public static final int X86_INS_VMASKMOVPS = 847;
  public static final int X86_INS_VMAXPD = 848;
  public static final int X86_INS_VMAXPS = 849;
  public static final int X86_INS_VMAXSD = 850;
  public static final int X86_INS_VMAXSS = 851;
  public static final int X86_INS_VMCALL = 852;
  public static final int X86_INS_VMCLEAR = 853;
  public static final int X86_INS_VMFUNC = 854;
  public static final int X86_INS_VMINPD = 855;
  public static final int X86_INS_VMINPS = 856;
  public static final int X86_INS_VMINSD = 857;
  public static final int X86_INS_VMINSS = 858;
  public static final int X86_INS_VMLAUNCH = 859;
  public static final int X86_INS_VMLOAD = 860;
  public static final int X86_INS_VMMCALL = 861;
  public static final int X86_INS_VMOVQ = 862;
  public static final int X86_INS_VVMOVQ = 863;
  public static final int X86_INS_VMOVDDUP = 864;
  public static final int X86_INS_VMOVD = 865;
  public static final int X86_INS_VMOVDQA32 = 866;
  public static final int X86_INS_VMOVDQA64 = 867;
  public static final int X86_INS_VMOVDQA = 868;
  public static final int X86_INS_VMOVDQU32 = 869;
  public static final int X86_INS_VMOVDQU64 = 870;
  public static final int X86_INS_VMOVDQU = 871;
  public static final int X86_INS_VMOVHLPS = 872;
  public static final int X86_INS_VMOVHPD = 873;
  public static final int X86_INS_VMOVHPS = 874;
  public static final int X86_INS_VMOVLHPS = 875;
  public static final int X86_INS_VMOVLPD = 876;
  public static final int X86_INS_VMOVLPS = 877;
  public static final int X86_INS_VMOVMSKPD = 878;
  public static final int X86_INS_VMOVMSKPS = 879;
  public static final int X86_INS_VMOVNTDQA = 880;
  public static final int X86_INS_VMOVNTDQ = 881;
  public static final int X86_INS_VMOVNTPD = 882;
  public static final int X86_INS_VMOVNTPS = 883;
  public static final int X86_INS_VMOVSD = 884;
  public static final int X86_INS_VMOVSHDUP = 885;
  public static final int X86_INS_VMOVSLDUP = 886;
  public static final int X86_INS_VMOVSS = 887;
  public static final int X86_INS_VMOVUPD = 888;
  public static final int X86_INS_VMOVUPS = 889;
  public static final int X86_INS_VMPSADBW = 890;
  public static final int X86_INS_VMPTRLD = 891;
  public static final int X86_INS_VMPTRST = 892;
  public static final int X86_INS_VMREAD = 893;
  public static final int X86_INS_VMRESUME = 894;
  public static final int X86_INS_VMRUN = 895;
  public static final int X86_INS_VMSAVE = 896;
  public static final int X86_INS_VMULPD = 897;
  public static final int X86_INS_VMULPS = 898;
  public static final int X86_INS_VMULSD = 899;
  public static final int X86_INS_VMULSS = 900;
  public static final int X86_INS_VMWRITE = 901;
  public static final int X86_INS_VMXOFF = 902;
  public static final int X86_INS_VMXON = 903;
  public static final int X86_INS_VPABSB = 904;
  public static final int X86_INS_VPABSD = 905;
  public static final int X86_INS_VPABSQ = 906;
  public static final int X86_INS_VPABSW = 907;
  public static final int X86_INS_VPACKSSDW = 908;
  public static final int X86_INS_VPACKSSWB = 909;
  public static final int X86_INS_VPACKUSDW = 910;
  public static final int X86_INS_VPACKUSWB = 911;
  public static final int X86_INS_VPADDB = 912;
  public static final int X86_INS_VPADDD = 913;
  public static final int X86_INS_VPADDQ = 914;
  public static final int X86_INS_VPADDSB = 915;
  public static final int X86_INS_VPADDSW = 916;
  public static final int X86_INS_VPADDUSB = 917;
  public static final int X86_INS_VPADDUSW = 918;
  public static final int X86_INS_VPADDW = 919;
  public static final int X86_INS_VPALIGNR = 920;
  public static final int X86_INS_VPANDD = 921;
  public static final int X86_INS_VPANDND = 922;
  public static final int X86_INS_VPANDNQ = 923;
  public static final int X86_INS_VPANDN = 924;
  public static final int X86_INS_VPANDQ = 925;
  public static final int X86_INS_VPAND = 926;
  public static final int X86_INS_VPAVGB = 927;
  public static final int X86_INS_VPAVGW = 928;
  public static final int X86_INS_VPBLENDD = 929;
  public static final int X86_INS_VPBLENDMD = 930;
  public static final int X86_INS_VPBLENDMQ = 931;
  public static final int X86_INS_VPBLENDVB = 932;
  public static final int X86_INS_VPBLENDW = 933;
  public static final int X86_INS_VPBROADCASTB = 934;
  public static final int X86_INS_VPBROADCASTD = 935;
  public static final int X86_INS_VPBROADCASTMB2Q = 936;
  public static final int X86_INS_VPBROADCASTMW2D = 937;
  public static final int X86_INS_VPBROADCASTQ = 938;
  public static final int X86_INS_VPBROADCASTW = 939;
  public static final int X86_INS_VPCLMULQDQ = 940;
  public static final int X86_INS_VPCMOV = 941;
  public static final int X86_INS_VPCMPD = 942;
  public static final int X86_INS_VPCMPEQB = 943;
  public static final int X86_INS_VPCMPEQD = 944;
  public static final int X86_INS_VPCMPEQQ = 945;
  public static final int X86_INS_VPCMPEQW = 946;
  public static final int X86_INS_VPCMPESTRI = 947;
  public static final int X86_INS_VPCMPESTRM = 948;
  public static final int X86_INS_VPCMPGTB = 949;
  public static final int X86_INS_VPCMPGTD = 950;
  public static final int X86_INS_VPCMPGTQ = 951;
  public static final int X86_INS_VPCMPGTW = 952;
  public static final int X86_INS_VPCMPISTRI = 953;
  public static final int X86_INS_VPCMPISTRM = 954;
  public static final int X86_INS_VPCMPQ = 955;
  public static final int X86_INS_VPCMPUD = 956;
  public static final int X86_INS_VPCMPUQ = 957;
  public static final int X86_INS_VPCOMB = 958;
  public static final int X86_INS_VPCOMD = 959;
  public static final int X86_INS_VPCOMQ = 960;
  public static final int X86_INS_VPCOMUB = 961;
  public static final int X86_INS_VPCOMUD = 962;
  public static final int X86_INS_VPCOMUQ = 963;
  public static final int X86_INS_VPCOMUW = 964;
  public static final int X86_INS_VPCOMW = 965;
  public static final int X86_INS_VPERM2F128 = 966;
  public static final int X86_INS_VPERM2I128 = 967;
  public static final int X86_INS_VPERMD = 968;
  public static final int X86_INS_VPERMI2D = 969;
  public static final int X86_INS_VPERMI2PD = 970;
  public static final int X86_INS_VPERMI2PS = 971;
  public static final int X86_INS_VPERMI2Q = 972;
  public static final int X86_INS_VPERMIL2PD = 973;
  public static final int X86_INS_VPERMIL2PS = 974;
  public static final int X86_INS_VPERMILPD = 975;
  public static final int X86_INS_VPERMILPS = 976;
  public static final int X86_INS_VPERMPD = 977;
  public static final int X86_INS_VPERMPS = 978;
  public static final int X86_INS_VPERMQ = 979;
  public static final int X86_INS_VPEXTRB = 980;
  public static final int X86_INS_VPEXTRD = 981;
  public static final int X86_INS_VPEXTRQ = 982;
  public static final int X86_INS_VPEXTRW = 983;
  public static final int X86_INS_VPGATHERDD = 984;
  public static final int X86_INS_VPGATHERDQ = 985;
  public static final int X86_INS_VPGATHERQD = 986;
  public static final int X86_INS_VPGATHERQQ = 987;
  public static final int X86_INS_VPHADDBD = 988;
  public static final int X86_INS_VPHADDBQ = 989;
  public static final int X86_INS_VPHADDBW = 990;
  public static final int X86_INS_VPHADDDQ = 991;
  public static final int X86_INS_VPHADDD = 992;
  public static final int X86_INS_VPHADDSW = 993;
  public static final int X86_INS_VPHADDUBD = 994;
  public static final int X86_INS_VPHADDUBQ = 995;
  public static final int X86_INS_VPHADDUBW = 996;
  public static final int X86_INS_VPHADDUDQ = 997;
  public static final int X86_INS_VPHADDUWD = 998;
  public static final int X86_INS_VPHADDUWQ = 999;
  public static final int X86_INS_VPHADDWD = 1000;
  public static final int X86_INS_VPHADDWQ = 1001;
  public static final int X86_INS_VPHADDW = 1002;
  public static final int X86_INS_VPHMINPOSUW = 1003;
  public static final int X86_INS_VPHSUBBW = 1004;
  public static final int X86_INS_VPHSUBDQ = 1005;
  public static final int X86_INS_VPHSUBD = 1006;
  public static final int X86_INS_VPHSUBSW = 1007;
  public static final int X86_INS_VPHSUBWD = 1008;
  public static final int X86_INS_VPHSUBW = 1009;
  public static final int X86_INS_VPINSRB = 1010;
  public static final int X86_INS_VPINSRD = 1011;
  public static final int X86_INS_VPINSRQ = 1012;
  public static final int X86_INS_VPINSRW = 1013;
  public static final int X86_INS_VPMACSDD = 1014;
  public static final int X86_INS_VPMACSDQH = 1015;
  public static final int X86_INS_VPMACSDQL = 1016;
  public static final int X86_INS_VPMACSSDD = 1017;
  public static final int X86_INS_VPMACSSDQH = 1018;
  public static final int X86_INS_VPMACSSDQL = 1019;
  public static final int X86_INS_VPMACSSWD = 1020;
  public static final int X86_INS_VPMACSSWW = 1021;
  public static final int X86_INS_VPMACSWD = 1022;
  public static final int X86_INS_VPMACSWW = 1023;
  public static final int X86_INS_VPMADCSSWD = 1024;
  public static final int X86_INS_VPMADCSWD = 1025;
  public static final int X86_INS_VPMADDUBSW = 1026;
  public static final int X86_INS_VPMADDWD = 1027;
  public static final int X86_INS_VPMASKMOVD = 1028;
  public static final int X86_INS_VPMASKMOVQ = 1029;
  public static final int X86_INS_VPMAXSB = 1030;
  public static final int X86_INS_VPMAXSD = 1031;
  public static final int X86_INS_VPMAXSW = 1032;
  public static final int X86_INS_VPMAXUB = 1033;
  public static final int X86_INS_VPMAXUD = 1034;
  public static final int X86_INS_VPMAXUW = 1035;
  public static final int X86_INS_VPMINSB = 1036;
  public static final int X86_INS_VPMINSD = 1037;
  public static final int X86_INS_VPMINSW = 1038;
  public static final int X86_INS_VPMINUB = 1039;
  public static final int X86_INS_VPMINUD = 1040;
  public static final int X86_INS_VPMINUW = 1041;
  public static final int X86_INS_VPMOVDB = 1042;
  public static final int X86_INS_VPMOVDW = 1043;
  public static final int X86_INS_VPMOVMSKB = 1044;
  public static final int X86_INS_VPMOVQB = 1045;
  public static final int X86_INS_VPMOVQD = 1046;
  public static final int X86_INS_VPMOVQW = 1047;
  public static final int X86_INS_VPMOVSDB = 1048;
  public static final int X86_INS_VPMOVSDW = 1049;
  public static final int X86_INS_VPMOVSQB = 1050;
  public static final int X86_INS_VPMOVSQD = 1051;
  public static final int X86_INS_VPMOVSQW = 1052;
  public static final int X86_INS_VPMOVSXBD = 1053;
  public static final int X86_INS_VPMOVSXBQ = 1054;
  public static final int X86_INS_VPMOVSXBW = 1055;
  public static final int X86_INS_VPMOVSXDQ = 1056;
  public static final int X86_INS_VPMOVSXWD = 1057;
  public static final int X86_INS_VPMOVSXWQ = 1058;
  public static final int X86_INS_VPMOVUSDB = 1059;
  public static final int X86_INS_VPMOVUSDW = 1060;
  public static final int X86_INS_VPMOVUSQB = 1061;
  public static final int X86_INS_VPMOVUSQD = 1062;
  public static final int X86_INS_VPMOVUSQW = 1063;
  public static final int X86_INS_VPMOVZXBD = 1064;
  public static final int X86_INS_VPMOVZXBQ = 1065;
  public static final int X86_INS_VPMOVZXBW = 1066;
  public static final int X86_INS_VPMOVZXDQ = 1067;
  public static final int X86_INS_VPMOVZXWD = 1068;
  public static final int X86_INS_VPMOVZXWQ = 1069;
  public static final int X86_INS_VPMULDQ = 1070;
  public static final int X86_INS_VPMULHRSW = 1071;
  public static final int X86_INS_VPMULHUW = 1072;
  public static final int X86_INS_VPMULHW = 1073;
  public static final int X86_INS_VPMULLD = 1074;
  public static final int X86_INS_VPMULLW = 1075;
  public static final int X86_INS_VPMULUDQ = 1076;
  public static final int X86_INS_VPORD = 1077;
  public static final int X86_INS_VPORQ = 1078;
  public static final int X86_INS_VPOR = 1079;
  public static final int X86_INS_VPPERM = 1080;
  public static final int X86_INS_VPROTB = 1081;
  public static final int X86_INS_VPROTD = 1082;
  public static final int X86_INS_VPROTQ = 1083;
  public static final int X86_INS_VPROTW = 1084;
  public static final int X86_INS_VPSADBW = 1085;
  public static final int X86_INS_VPSCATTERDD = 1086;
  public static final int X86_INS_VPSCATTERDQ = 1087;
  public static final int X86_INS_VPSCATTERQD = 1088;
  public static final int X86_INS_VPSCATTERQQ = 1089;
  public static final int X86_INS_VPSHAB = 1090;
  public static final int X86_INS_VPSHAD = 1091;
  public static final int X86_INS_VPSHAQ = 1092;
  public static final int X86_INS_VPSHAW = 1093;
  public static final int X86_INS_VPSHLB = 1094;
  public static final int X86_INS_VPSHLD = 1095;
  public static final int X86_INS_VPSHLQ = 1096;
  public static final int X86_INS_VPSHLW = 1097;
  public static final int X86_INS_VPSHUFB = 1098;
  public static final int X86_INS_VPSHUFD = 1099;
  public static final int X86_INS_VPSHUFHW = 1100;
  public static final int X86_INS_VPSHUFLW = 1101;
  public static final int X86_INS_VPSIGNB = 1102;
  public static final int X86_INS_VPSIGND = 1103;
  public static final int X86_INS_VPSIGNW = 1104;
  public static final int X86_INS_VPSLLDQ = 1105;
  public static final int X86_INS_VPSLLD = 1106;
  public static final int X86_INS_VPSLLQ = 1107;
  public static final int X86_INS_VPSLLVD = 1108;
  public static final int X86_INS_VPSLLVQ = 1109;
  public static final int X86_INS_VPSLLW = 1110;
  public static final int X86_INS_VPSRAD = 1111;
  public static final int X86_INS_VPSRAQ = 1112;
  public static final int X86_INS_VPSRAVD = 1113;
  public static final int X86_INS_VPSRAVQ = 1114;
  public static final int X86_INS_VPSRAW = 1115;
  public static final int X86_INS_VPSRLDQ = 1116;
  public static final int X86_INS_VPSRLD = 1117;
  public static final int X86_INS_VPSRLQ = 1118;
  public static final int X86_INS_VPSRLVD = 1119;
  public static final int X86_INS_VPSRLVQ = 1120;
  public static final int X86_INS_VPSRLW = 1121;
  public static final int X86_INS_VPSUBB = 1122;
  public static final int X86_INS_VPSUBD = 1123;
  public static final int X86_INS_VPSUBQ = 1124;
  public static final int X86_INS_VPSUBSB = 1125;
  public static final int X86_INS_VPSUBSW = 1126;
  public static final int X86_INS_VPSUBUSB = 1127;
  public static final int X86_INS_VPSUBUSW = 1128;
  public static final int X86_INS_VPSUBW = 1129;
  public static final int X86_INS_VPTESTMD = 1130;
  public static final int X86_INS_VPTESTMQ = 1131;
  public static final int X86_INS_VPTEST = 1132;
  public static final int X86_INS_VPUNPCKHBW = 1133;
  public static final int X86_INS_VPUNPCKHDQ = 1134;
  public static final int X86_INS_VPUNPCKHQDQ = 1135;
  public static final int X86_INS_VPUNPCKHWD = 1136;
  public static final int X86_INS_VPUNPCKLBW = 1137;
  public static final int X86_INS_VPUNPCKLDQ = 1138;
  public static final int X86_INS_VPUNPCKLQDQ = 1139;
  public static final int X86_INS_VPUNPCKLWD = 1140;
  public static final int X86_INS_VPXORD = 1141;
  public static final int X86_INS_VPXORQ = 1142;
  public static final int X86_INS_VPXOR = 1143;
  public static final int X86_INS_VRCP14PD = 1144;
  public static final int X86_INS_VRCP14PS = 1145;
  public static final int X86_INS_VRCP14SD = 1146;
  public static final int X86_INS_VRCP14SS = 1147;
  public static final int X86_INS_VRCPPS = 1148;
  public static final int X86_INS_VRCPSS = 1149;
  public static final int X86_INS_VRNDSCALESD = 1150;
  public static final int X86_INS_VRNDSCALESS = 1151;
  public static final int X86_INS_VRNDSCALEPD = 1152;
  public static final int X86_INS_VRNDSCALEPS = 1153;
  public static final int X86_INS_VROUNDPD = 1154;
  public static final int X86_INS_VROUNDPS = 1155;
  public static final int X86_INS_VROUNDSD = 1156;
  public static final int X86_INS_VROUNDSS = 1157;
  public static final int X86_INS_VRSQRT14PD = 1158;
  public static final int X86_INS_VRSQRT14PS = 1159;
  public static final int X86_INS_VRSQRT14SD = 1160;
  public static final int X86_INS_VRSQRT14SS = 1161;
  public static final int X86_INS_VRSQRTPS = 1162;
  public static final int X86_INS_VRSQRTSS = 1163;
  public static final int X86_INS_VSCATTERDPD = 1164;
  public static final int X86_INS_VSCATTERDPS = 1165;
  public static final int X86_INS_VSCATTERQPD = 1166;
  public static final int X86_INS_VSCATTERQPS = 1167;
  public static final int X86_INS_VSHUFPD = 1168;
  public static final int X86_INS_VSHUFPS = 1169;
  public static final int X86_INS_VSQRTPD = 1170;
  public static final int X86_INS_VSQRT = 1171;
  public static final int X86_INS_VSQRTPS = 1172;
  public static final int X86_INS_VSQRTSD = 1173;
  public static final int X86_INS_VSQRTSS = 1174;
  public static final int X86_INS_VSTMXCSR = 1175;
  public static final int X86_INS_VSUBPD = 1176;
  public static final int X86_INS_VSUBPS = 1177;
  public static final int X86_INS_VSUBSD = 1178;
  public static final int X86_INS_VSUBSS = 1179;
  public static final int X86_INS_VTESTPD = 1180;
  public static final int X86_INS_VTESTPS = 1181;
  public static final int X86_INS_VUNPCKHPD = 1182;
  public static final int X86_INS_VUNPCKHPS = 1183;
  public static final int X86_INS_VUNPCKLPD = 1184;
  public static final int X86_INS_VUNPCKLPS = 1185;
  public static final int X86_INS_VZEROALL = 1186;
  public static final int X86_INS_VZEROUPPER = 1187;
  public static final int X86_INS_WAIT = 1188;
  public static final int X86_INS_WBINVD = 1189;
  public static final int X86_INS_WRFSBASE = 1190;
  public static final int X86_INS_WRGSBASE = 1191;
  public static final int X86_INS_WRMSR = 1192;
  public static final int X86_INS_XABORT = 1193;
  public static final int X86_INS_XACQUIRE = 1194;
  public static final int X86_INS_XBEGIN = 1195;
  public static final int X86_INS_XCHG = 1196;
  public static final int X86_INS_FXCH = 1197;
  public static final int X86_INS_XCRYPTCBC = 1198;
  public static final int X86_INS_XCRYPTCFB = 1199;
  public static final int X86_INS_XCRYPTCTR = 1200;
  public static final int X86_INS_XCRYPTECB = 1201;
  public static final int X86_INS_XCRYPTOFB = 1202;
  public static final int X86_INS_XEND = 1203;
  public static final int X86_INS_XGETBV = 1204;
  public static final int X86_INS_XLATB = 1205;
  public static final int X86_INS_XRELEASE = 1206;
  public static final int X86_INS_XRSTOR = 1207;
  public static final int X86_INS_XRSTOR64 = 1208;
  public static final int X86_INS_XSAVE = 1209;
  public static final int X86_INS_XSAVE64 = 1210;
  public static final int X86_INS_XSAVEOPT = 1211;
  public static final int X86_INS_XSAVEOPT64 = 1212;
  public static final int X86_INS_XSETBV = 1213;
  public static final int X86_INS_XSHA1 = 1214;
  public static final int X86_INS_XSHA256 = 1215;
  public static final int X86_INS_XSTORE = 1216;
  public static final int X86_INS_XTEST = 1217;

  // all Intel instruction groups
  public static final int X86_GRP_INVALID = 0;
  public static final int X86_GRP_3DNOW = 1;
  public static final int X86_GRP_AES = 2;
  public static final int X86_GRP_ADX = 3;
  public static final int X86_GRP_AVX = 4;
  public static final int X86_GRP_AVX2 = 5;
  public static final int X86_GRP_AVX512 = 6;
  public static final int X86_GRP_BMI = 7;
  public static final int X86_GRP_BMI2 = 8;
  public static final int X86_GRP_CMOV = 9;
  public static final int X86_GRP_F16C = 10;
  public static final int X86_GRP_FMA = 11;
  public static final int X86_GRP_FMA4 = 12;
  public static final int X86_GRP_FSGSBASE = 13;
  public static final int X86_GRP_HLE = 14;
  public static final int X86_GRP_MMX = 15;
  public static final int X86_GRP_MODE32 = 16;
  public static final int X86_GRP_MODE64 = 17;
  public static final int X86_GRP_RTM = 18;
  public static final int X86_GRP_SHA = 19;
  public static final int X86_GRP_SSE1 = 20;
  public static final int X86_GRP_SSE2 = 21;
  public static final int X86_GRP_SSE3 = 22;
  public static final int X86_GRP_SSE41 = 23;
  public static final int X86_GRP_SSE42 = 24;
  public static final int X86_GRP_SSE4A = 25;
  public static final int X86_GRP_SSSE3 = 26;
  public static final int X86_GRP_PCLMUL = 27;
  public static final int X86_GRP_XOP = 28;

}
