# Capstone Python bindings, by Nguyen Anh Quynnh <aquynh@gmail.com>

import ctypes, ctypes.util

# ARM64 operand shift type
ARM64_SFT_INVALID = 0
ARM64_SFT_LSL = 1
ARM64_SFT_MSL = 2
ARM64_SFT_LSR = 3
ARM64_SFT_ASR = 4
ARM64_SFT_ROR = 5

# ARM64 extension type (for operands)
ARM64_EXT_INVALID = 0
ARM64_EXT_UXTB = 1
ARM64_EXT_UXTH = 2
ARM64_EXT_UXTW = 3
ARM64_EXT_UXTX = 4
ARM64_EXT_SXTB = 5
ARM64_EXT_SXTH = 6
ARM64_EXT_SXTW = 7
ARM64_EXT_SXTX = 8

# ARM64 code condition type
ARM64_CC_INVALID = 0
ARM64_CC_EQ = 1
ARM64_CC_NE = 2
ARM64_CC_HS = 3
ARM64_CC_LO = 4
ARM64_CC_MI = 5
ARM64_CC_PL = 6
ARM64_CC_VS = 7
ARM64_CC_VC = 8
ARM64_CC_HI = 9
ARM64_CC_LS = 10
ARM64_CC_GE = 11
ARM64_CC_LT = 12
ARM64_CC_GT = 13
ARM64_CC_LE = 14
ARM64_CC_AL = 15
ARM64_CC_NV = 16

# Operand type
ARM64_OP_INVALID = 0  # Uninitialized.
ARM64_OP_REG = 1   # Register operand.
ARM64_OP_CIMM = 2   # C-Immediate operand.
ARM64_OP_IMM = 3   # Immediate operand.
ARM64_OP_FP = 4    # Floating-Point immediate operand.
ARM64_OP_MEM = 5   # Memory operand


# define the API
class arm64_op_mem(ctypes.Structure):
    _fields_ = (
        ('base', ctypes.c_uint),
        ('index', ctypes.c_uint),
        ('disp', ctypes.c_int64),
    )

class arm64_op_shift(ctypes.Structure):
    _fields_ = (
        ('type', ctypes.c_uint),
        ('value', ctypes.c_uint),
    )

class arm64_op_value(ctypes.Union):
    _fields_ = (
        ('reg', ctypes.c_uint),
        ('imm', ctypes.c_int64),
        ('fp', ctypes.c_double),
        ('mem', arm64_op_mem),
    )

class arm64_op(ctypes.Structure):
    _fields_ = (
        ('shift', arm64_op_shift),
        ('ext', ctypes.c_uint),
        ('type', ctypes.c_uint),
        ('value', arm64_op_value),
    )

class _cs_arm64(ctypes.Structure):
    _fields_ = (
        ('cc', ctypes.c_uint),
        ('update_flags', ctypes.c_bool),
        ('writeback', ctypes.c_bool),
        ('op_count', ctypes.c_uint8),
        ('op_info', arm64_op * 32),
    )

def get_arch_info(a):
    op_info = []
    for i in a.op_info:
        if i.type == 0:
            break
        op_info.append(i)
    return (a.cc, a.update_flags, a.writeback, op_info)


# ARM registers
ARM64_REG_INVALID = 0
ARM64_REG_NZCV = 1
ARM64_REG_WSP = 2
ARM64_REG_WZR = 3
ARM64_REG_SP = 4
ARM64_REG_XZR = 5
ARM64_REG_B0 = 6
ARM64_REG_B1 = 7
ARM64_REG_B2 = 8
ARM64_REG_B3 = 9
ARM64_REG_B4 = 10
ARM64_REG_B5 = 11
ARM64_REG_B6 = 12
ARM64_REG_B7 = 13
ARM64_REG_B8 = 14
ARM64_REG_B9 = 15
ARM64_REG_B10 = 16
ARM64_REG_B11 = 17
ARM64_REG_B12 = 18
ARM64_REG_B13 = 19
ARM64_REG_B14 = 20
ARM64_REG_B15 = 21
ARM64_REG_B16 = 22
ARM64_REG_B17 = 23
ARM64_REG_B18 = 24
ARM64_REG_B19 = 25
ARM64_REG_B20 = 26
ARM64_REG_B21 = 27
ARM64_REG_B22 = 28
ARM64_REG_B23 = 29
ARM64_REG_B24 = 30
ARM64_REG_B25 = 31
ARM64_REG_B26 = 32
ARM64_REG_B27 = 33
ARM64_REG_B28 = 34
ARM64_REG_B29 = 35
ARM64_REG_B30 = 36
ARM64_REG_B31 = 37
ARM64_REG_D0 = 38
ARM64_REG_D1 = 39
ARM64_REG_D2 = 40
ARM64_REG_D3 = 41
ARM64_REG_D4 = 42
ARM64_REG_D5 = 43
ARM64_REG_D6 = 44
ARM64_REG_D7 = 45
ARM64_REG_D8 = 46
ARM64_REG_D9 = 47
ARM64_REG_D10 = 48
ARM64_REG_D11 = 49
ARM64_REG_D12 = 50
ARM64_REG_D13 = 51
ARM64_REG_D14 = 52
ARM64_REG_D15 = 53
ARM64_REG_D16 = 54
ARM64_REG_D17 = 55
ARM64_REG_D18 = 56
ARM64_REG_D19 = 57
ARM64_REG_D20 = 58
ARM64_REG_D21 = 59
ARM64_REG_D22 = 60
ARM64_REG_D23 = 61
ARM64_REG_D24 = 62
ARM64_REG_D25 = 63
ARM64_REG_D26 = 64
ARM64_REG_D27 = 65
ARM64_REG_D28 = 66
ARM64_REG_D29 = 67
ARM64_REG_D30 = 68
ARM64_REG_D31 = 69
ARM64_REG_H0 = 70
ARM64_REG_H1 = 71
ARM64_REG_H2 = 72
ARM64_REG_H3 = 73
ARM64_REG_H4 = 74
ARM64_REG_H5 = 75
ARM64_REG_H6 = 76
ARM64_REG_H7 = 77
ARM64_REG_H8 = 78
ARM64_REG_H9 = 79
ARM64_REG_H10 = 80
ARM64_REG_H11 = 81
ARM64_REG_H12 = 82
ARM64_REG_H13 = 83
ARM64_REG_H14 = 84
ARM64_REG_H15 = 85
ARM64_REG_H16 = 86
ARM64_REG_H17 = 87
ARM64_REG_H18 = 88
ARM64_REG_H19 = 89
ARM64_REG_H20 = 90
ARM64_REG_H21 = 91
ARM64_REG_H22 = 92
ARM64_REG_H23 = 93
ARM64_REG_H24 = 94
ARM64_REG_H25 = 95
ARM64_REG_H26 = 96
ARM64_REG_H27 = 97
ARM64_REG_H28 = 98
ARM64_REG_H29 = 99
ARM64_REG_H30 = 100
ARM64_REG_H31 = 101
ARM64_REG_Q0 = 102
ARM64_REG_Q1 = 103
ARM64_REG_Q2 = 104
ARM64_REG_Q3 = 105
ARM64_REG_Q4 = 106
ARM64_REG_Q5 = 107
ARM64_REG_Q6 = 108
ARM64_REG_Q7 = 109
ARM64_REG_Q8 = 110
ARM64_REG_Q9 = 111
ARM64_REG_Q10 = 112
ARM64_REG_Q11 = 113
ARM64_REG_Q12 = 114
ARM64_REG_Q13 = 115
ARM64_REG_Q14 = 116
ARM64_REG_Q15 = 117
ARM64_REG_Q16 = 118
ARM64_REG_Q17 = 119
ARM64_REG_Q18 = 120
ARM64_REG_Q19 = 121
ARM64_REG_Q20 = 122
ARM64_REG_Q21 = 123
ARM64_REG_Q22 = 124
ARM64_REG_Q23 = 125
ARM64_REG_Q24 = 126
ARM64_REG_Q25 = 127
ARM64_REG_Q26 = 128
ARM64_REG_Q27 = 129
ARM64_REG_Q28 = 130
ARM64_REG_Q29 = 131
ARM64_REG_Q30 = 132
ARM64_REG_Q31 = 133
ARM64_REG_S0 = 134
ARM64_REG_S1 = 135
ARM64_REG_S2 = 136
ARM64_REG_S3 = 137
ARM64_REG_S4 = 138
ARM64_REG_S5 = 139
ARM64_REG_S6 = 140
ARM64_REG_S7 = 141
ARM64_REG_S8 = 142
ARM64_REG_S9 = 143
ARM64_REG_S10 = 144
ARM64_REG_S11 = 145
ARM64_REG_S12 = 146
ARM64_REG_S13 = 147
ARM64_REG_S14 = 148
ARM64_REG_S15 = 149
ARM64_REG_S16 = 150
ARM64_REG_S17 = 151
ARM64_REG_S18 = 152
ARM64_REG_S19 = 153
ARM64_REG_S20 = 154
ARM64_REG_S21 = 155
ARM64_REG_S22 = 156
ARM64_REG_S23 = 157
ARM64_REG_S24 = 158
ARM64_REG_S25 = 159
ARM64_REG_S26 = 160
ARM64_REG_S27 = 161
ARM64_REG_S28 = 162
ARM64_REG_S29 = 163
ARM64_REG_S30 = 164
ARM64_REG_S31 = 165
ARM64_REG_W0 = 166
ARM64_REG_W1 = 167
ARM64_REG_W2 = 168
ARM64_REG_W3 = 169
ARM64_REG_W4 = 170
ARM64_REG_W5 = 171
ARM64_REG_W6 = 172
ARM64_REG_W7 = 173
ARM64_REG_W8 = 174
ARM64_REG_W9 = 175
ARM64_REG_W10 = 176
ARM64_REG_W11 = 177
ARM64_REG_W12 = 178
ARM64_REG_W13 = 179
ARM64_REG_W14 = 180
ARM64_REG_W15 = 181
ARM64_REG_W16 = 182
ARM64_REG_W17 = 183
ARM64_REG_W18 = 184
ARM64_REG_W19 = 185
ARM64_REG_W20 = 186
ARM64_REG_W21 = 187
ARM64_REG_W22 = 188
ARM64_REG_W23 = 189
ARM64_REG_W24 = 190
ARM64_REG_W25 = 191
ARM64_REG_W26 = 192
ARM64_REG_W27 = 193
ARM64_REG_W28 = 194
ARM64_REG_W29 = 195
ARM64_REG_W30 = 196
ARM64_REG_X0 = 197
ARM64_REG_X1 = 198
ARM64_REG_X2 = 199
ARM64_REG_X3 = 200
ARM64_REG_X4 = 201
ARM64_REG_X5 = 202
ARM64_REG_X6 = 203
ARM64_REG_X7 = 204
ARM64_REG_X8 = 205
ARM64_REG_X9 = 206
ARM64_REG_X10 = 207
ARM64_REG_X11 = 208
ARM64_REG_X12 = 209
ARM64_REG_X13 = 210
ARM64_REG_X14 = 211
ARM64_REG_X15 = 212
ARM64_REG_X16 = 213
ARM64_REG_X17 = 214
ARM64_REG_X18 = 215
ARM64_REG_X19 = 216
ARM64_REG_X20 = 217
ARM64_REG_X21 = 218
ARM64_REG_X22 = 219
ARM64_REG_X23 = 220
ARM64_REG_X24 = 221
ARM64_REG_X25 = 222
ARM64_REG_X26 = 223
ARM64_REG_X27 = 224
ARM64_REG_X28 = 225
ARM64_REG_X29 = 226
ARM64_REG_X30 = 227

# ARM64 instructions
ARM64_INS_INVALID = 0
ARM64_INS_ADC = 1
ARM64_INS_ADDHN2 = 2
ARM64_INS_ADDHN = 3
ARM64_INS_ADDP = 4
ARM64_INS_ADD = 5
ARM64_INS_CMN = 6
ARM64_INS_ADRP = 7
ARM64_INS_ADR = 8
ARM64_INS_AND = 9
ARM64_INS_ASR = 10
ARM64_INS_AT = 11
ARM64_INS_BFI = 12
ARM64_INS_BFM = 13
ARM64_INS_BFXIL = 14
ARM64_INS_BIC = 15
ARM64_INS_BIF = 16
ARM64_INS_BIT = 17
ARM64_INS_BLR = 18
ARM64_INS_BL = 19
ARM64_INS_BRK = 20
ARM64_INS_BR = 21
ARM64_INS_BSL = 22
ARM64_INS_B = 23
ARM64_INS_CBNZ = 24
ARM64_INS_CBZ = 25
ARM64_INS_CCMN = 26
ARM64_INS_CCMP = 27
ARM64_INS_CLREX = 28
ARM64_INS_CLS = 29
ARM64_INS_CLZ = 30
ARM64_INS_CMEQ = 31
ARM64_INS_CMGE = 32
ARM64_INS_CMGT = 33
ARM64_INS_CMHI = 34
ARM64_INS_CMHS = 35
ARM64_INS_CMLE = 36
ARM64_INS_CMLT = 37
ARM64_INS_CMP = 38
ARM64_INS_CMTST = 39
ARM64_INS_CRC32B = 40
ARM64_INS_CRC32CB = 41
ARM64_INS_CRC32CH = 42
ARM64_INS_CRC32CW = 43
ARM64_INS_CRC32CX = 44
ARM64_INS_CRC32H = 45
ARM64_INS_CRC32W = 46
ARM64_INS_CRC32X = 47
ARM64_INS_CSEL = 48
ARM64_INS_CSINC = 49
ARM64_INS_CSINV = 50
ARM64_INS_CSNEG = 51
ARM64_INS_DCPS1 = 52
ARM64_INS_DCPS2 = 53
ARM64_INS_DCPS3 = 54
ARM64_INS_DC = 55
ARM64_INS_DMB = 56
ARM64_INS_DRPS = 57
ARM64_INS_DSB = 58
ARM64_INS_EON = 59
ARM64_INS_EOR = 60
ARM64_INS_ERET = 61
ARM64_INS_EXTR = 62
ARM64_INS_FABD = 63
ARM64_INS_FABS = 64
ARM64_INS_FACGE = 65
ARM64_INS_FACGT = 66
ARM64_INS_FADDP = 67
ARM64_INS_FADD = 68
ARM64_INS_FCCMPE = 69
ARM64_INS_FCCMP = 70
ARM64_INS_FCMEQ = 71
ARM64_INS_FCMGE = 72
ARM64_INS_FCMGT = 73
ARM64_INS_FCMLE = 74
ARM64_INS_FCMLT = 75
ARM64_INS_FCMP = 76
ARM64_INS_FCMPE = 77
ARM64_INS_FCSEL = 78
ARM64_INS_FCVTAS = 79
ARM64_INS_FCVTAU = 80
ARM64_INS_FCVTMS = 81
ARM64_INS_FCVTMU = 82
ARM64_INS_FCVTNS = 83
ARM64_INS_FCVTNU = 84
ARM64_INS_FCVTPS = 85
ARM64_INS_FCVTPU = 86
ARM64_INS_FCVTZS = 87
ARM64_INS_FCVTZU = 88
ARM64_INS_FCVT = 89
ARM64_INS_FDIV = 90
ARM64_INS_FMADD = 91
ARM64_INS_FMAXNMP = 92
ARM64_INS_FMAXNM = 93
ARM64_INS_FMAXP = 94
ARM64_INS_FMAX = 95
ARM64_INS_FMINNMP = 96
ARM64_INS_FMINNM = 97
ARM64_INS_FMINP = 98
ARM64_INS_FMIN = 99
ARM64_INS_FMLA = 100
ARM64_INS_FMLS = 101
ARM64_INS_FMOV = 102
ARM64_INS_FMSUB = 103
ARM64_INS_FMULX = 104
ARM64_INS_FMUL = 105
ARM64_INS_FNEG = 106
ARM64_INS_FNMADD = 107
ARM64_INS_FNMSUB = 108
ARM64_INS_FNMUL = 109
ARM64_INS_FRECPS = 110
ARM64_INS_FRINTA = 111
ARM64_INS_FRINTI = 112
ARM64_INS_FRINTM = 113
ARM64_INS_FRINTN = 114
ARM64_INS_FRINTP = 115
ARM64_INS_FRINTX = 116
ARM64_INS_FRINTZ = 117
ARM64_INS_FRSQRTS = 118
ARM64_INS_FSQRT = 119
ARM64_INS_FSUB = 120
ARM64_INS_HINT = 121
ARM64_INS_HLT = 122
ARM64_INS_HVC = 123
ARM64_INS_IC = 124
ARM64_INS_INS = 125
ARM64_INS_ISB = 126
ARM64_INS_LDARB = 127
ARM64_INS_LDAR = 128
ARM64_INS_LDARH = 129
ARM64_INS_LDAXP = 130
ARM64_INS_LDAXRB = 131
ARM64_INS_LDAXR = 132
ARM64_INS_LDAXRH = 133
ARM64_INS_LDPSW = 134
ARM64_INS_LDRSB = 135
ARM64_INS_LDURSB = 136
ARM64_INS_LDRSH = 137
ARM64_INS_LDURSH = 138
ARM64_INS_LDRSW = 139
ARM64_INS_LDR = 140
ARM64_INS_LDTRSB = 141
ARM64_INS_LDTRSH = 142
ARM64_INS_LDTRSW = 143
ARM64_INS_LDURSW = 144
ARM64_INS_LDXP = 145
ARM64_INS_LDXRB = 146
ARM64_INS_LDXR = 147
ARM64_INS_LDXRH = 148
ARM64_INS_LDRH = 149
ARM64_INS_LDURH = 150
ARM64_INS_STRH = 151
ARM64_INS_STURH = 152
ARM64_INS_LDTRH = 153
ARM64_INS_STTRH = 154
ARM64_INS_LDUR = 155
ARM64_INS_STR = 156
ARM64_INS_STUR = 157
ARM64_INS_LDTR = 158
ARM64_INS_STTR = 159
ARM64_INS_LDRB = 160
ARM64_INS_LDURB = 161
ARM64_INS_STRB = 162
ARM64_INS_STURB = 163
ARM64_INS_LDTRB = 164
ARM64_INS_STTRB = 165
ARM64_INS_LDP = 166
ARM64_INS_LDNP = 167
ARM64_INS_STNP = 168
ARM64_INS_STP = 169
ARM64_INS_LSL = 170
ARM64_INS_LSR = 171
ARM64_INS_MADD = 172
ARM64_INS_MLA = 173
ARM64_INS_MLS = 174
ARM64_INS_MOVI = 175
ARM64_INS_MOVK = 176
ARM64_INS_MOVN = 177
ARM64_INS_MOVZ = 178
ARM64_INS_MRS = 179
ARM64_INS_MSR = 180
ARM64_INS_MSUB = 181
ARM64_INS_MUL = 182
ARM64_INS_MVNI = 183
ARM64_INS_MVN = 184
ARM64_INS_ORN = 185
ARM64_INS_ORR = 186
ARM64_INS_PMULL2 = 187
ARM64_INS_PMULL = 188
ARM64_INS_PMUL = 189
ARM64_INS_PRFM = 190
ARM64_INS_PRFUM = 191
ARM64_INS_SQRSHRUN2 = 192
ARM64_INS_SQRSHRUN = 193
ARM64_INS_SQSHRUN2 = 194
ARM64_INS_SQSHRUN = 195
ARM64_INS_RADDHN2 = 196
ARM64_INS_RADDHN = 197
ARM64_INS_RBIT = 198
ARM64_INS_RET = 199
ARM64_INS_REV16 = 200
ARM64_INS_REV32 = 201
ARM64_INS_REV = 202
ARM64_INS_ROR = 203
ARM64_INS_RSHRN2 = 204
ARM64_INS_RSHRN = 205
ARM64_INS_RSUBHN2 = 206
ARM64_INS_RSUBHN = 207
ARM64_INS_SABAL2 = 208
ARM64_INS_SABAL = 209
ARM64_INS_SABA = 210
ARM64_INS_SABDL2 = 211
ARM64_INS_SABDL = 212
ARM64_INS_SABD = 213
ARM64_INS_SADDL2 = 214
ARM64_INS_SADDL = 215
ARM64_INS_SADDW2 = 216
ARM64_INS_SADDW = 217
ARM64_INS_SBC = 218
ARM64_INS_SBFIZ = 219
ARM64_INS_SBFM = 220
ARM64_INS_SBFX = 221
ARM64_INS_SCVTF = 222
ARM64_INS_SDIV = 223
ARM64_INS_SHADD = 224
ARM64_INS_SHL = 225
ARM64_INS_SHRN2 = 226
ARM64_INS_SHRN = 227
ARM64_INS_SHSUB = 228
ARM64_INS_SLI = 229
ARM64_INS_SMADDL = 230
ARM64_INS_SMAXP = 231
ARM64_INS_SMAX = 232
ARM64_INS_SMC = 233
ARM64_INS_SMINP = 234
ARM64_INS_SMIN = 235
ARM64_INS_SMLAL2 = 236
ARM64_INS_SMLAL = 237
ARM64_INS_SMLSL2 = 238
ARM64_INS_SMLSL = 239
ARM64_INS_SMOV = 240
ARM64_INS_SMSUBL = 241
ARM64_INS_SMULH = 242
ARM64_INS_SMULL2 = 243
ARM64_INS_SMULL = 244
ARM64_INS_SQADD = 245
ARM64_INS_SQDMLAL2 = 246
ARM64_INS_SQDMLAL = 247
ARM64_INS_SQDMLSL2 = 248
ARM64_INS_SQDMLSL = 249
ARM64_INS_SQDMULH = 250
ARM64_INS_SQDMULL2 = 251
ARM64_INS_SQDMULL = 252
ARM64_INS_SQRDMULH = 253
ARM64_INS_SQRSHL = 254
ARM64_INS_SQRSHRN2 = 255
ARM64_INS_SQRSHRN = 256
ARM64_INS_SQSHLU = 257
ARM64_INS_SQSHL = 258
ARM64_INS_SQSHRN2 = 259
ARM64_INS_SQSHRN = 260
ARM64_INS_SQSUB = 261
ARM64_INS_SRHADD = 262
ARM64_INS_SRI = 263
ARM64_INS_SRSHL = 264
ARM64_INS_SRSHR = 265
ARM64_INS_SRSRA = 266
ARM64_INS_SSHLL2 = 267
ARM64_INS_SSHLL = 268
ARM64_INS_SSHL = 269
ARM64_INS_SSHR = 270
ARM64_INS_SSRA = 271
ARM64_INS_SSUBL2 = 272
ARM64_INS_SSUBL = 273
ARM64_INS_SSUBW2 = 274
ARM64_INS_SSUBW = 275
ARM64_INS_STLRB = 276
ARM64_INS_STLR = 277
ARM64_INS_STLRH = 278
ARM64_INS_STLXP = 279
ARM64_INS_STLXRB = 280
ARM64_INS_STLXR = 281
ARM64_INS_STLXRH = 282
ARM64_INS_STXP = 283
ARM64_INS_STXRB = 284
ARM64_INS_STXR = 285
ARM64_INS_STXRH = 286
ARM64_INS_SUBHN2 = 287
ARM64_INS_SUBHN = 288
ARM64_INS_SUB = 289
ARM64_INS_SVC = 290
ARM64_INS_SXTB = 291
ARM64_INS_SXTH = 292
ARM64_INS_SXTW = 293
ARM64_INS_SYSL = 294
ARM64_INS_SYS = 295
ARM64_INS_TBNZ = 296
ARM64_INS_TBZ = 297
ARM64_INS_TLBI = 298
ARM64_INS_TST = 299
ARM64_INS_UABAL2 = 300
ARM64_INS_UABAL = 301
ARM64_INS_UABA = 302
ARM64_INS_UABDL2 = 303
ARM64_INS_UABDL = 304
ARM64_INS_UABD = 305
ARM64_INS_UADDL2 = 306
ARM64_INS_UADDL = 307
ARM64_INS_UADDW2 = 308
ARM64_INS_UADDW = 309
ARM64_INS_UBFIZ = 310
ARM64_INS_UBFM = 311
ARM64_INS_UBFX = 312
ARM64_INS_UCVTF = 313
ARM64_INS_UDIV = 314
ARM64_INS_UHADD = 315
ARM64_INS_UHSUB = 316
ARM64_INS_UMADDL = 317
ARM64_INS_UMAXP = 318
ARM64_INS_UMAX = 319
ARM64_INS_UMINP = 320
ARM64_INS_UMIN = 321
ARM64_INS_UMLAL2 = 322
ARM64_INS_UMLAL = 323
ARM64_INS_UMLSL2 = 324
ARM64_INS_UMLSL = 325
ARM64_INS_UMOV = 326
ARM64_INS_UMSUBL = 327
ARM64_INS_UMULH = 328
ARM64_INS_UMULL2 = 329
ARM64_INS_UMULL = 330
ARM64_INS_UQADD = 331
ARM64_INS_UQRSHL = 332
ARM64_INS_UQRSHRN2 = 333
ARM64_INS_UQRSHRN = 334
ARM64_INS_UQSHL = 335
ARM64_INS_UQSHRN2 = 336
ARM64_INS_UQSHRN = 337
ARM64_INS_UQSUB = 338
ARM64_INS_URHADD = 339
ARM64_INS_URSHL = 340
ARM64_INS_URSHR = 341
ARM64_INS_URSRA = 342
ARM64_INS_USHLL2 = 343
ARM64_INS_USHLL = 344
ARM64_INS_USHL = 345
ARM64_INS_USHR = 346
ARM64_INS_USRA = 347
ARM64_INS_USUBL2 = 348
ARM64_INS_USUBL = 349
ARM64_INS_USUBW2 = 350
ARM64_INS_USUBW = 351
ARM64_INS_UXTB = 352
ARM64_INS_UXTH = 353

# ARM64 group of instructions
ARM64_GRP_INVALID = 0
ARM64_GRP_NEON = 1

