# Capstone Python bindings, by Nguyen Anh Quynnh <aquynh@gmail.com>

import ctypes, ctypes.util

# Operand type
X86_OP_INVALID = 0  # Uninitialized.
X86_OP_REG = 1   # Register operand.
X86_OP_IMM = 2   # Immediate operand.
X86_OP_FP = 3    # Floating-Point immediate operand.
X86_OP_MEM = 4   # Memory operand

# define the API
class x86_op_mem(ctypes.Structure):
    _fields_ = (
        ('base', ctypes.c_uint),
        ('index', ctypes.c_uint),
        ('scale', ctypes.c_int),
        ('disp', ctypes.c_int64),
    )

class x86_op_value(ctypes.Union):
    _fields_ = (
        ('reg', ctypes.c_uint),
        ('imm', ctypes.c_int64),
        ('fp', ctypes.c_double),
        ('mem', x86_op_mem),
    )

class x86_op(ctypes.Structure):
    _fields_ = (
        ('type', ctypes.c_uint),
        ('value', x86_op_value),
    )

class _cs_x86(ctypes.Structure):
    _fields_ = (
        ('prefix', ctypes.c_uint8 * 5),
        ('segment', ctypes.c_uint),
        ('opcode', ctypes.c_uint8 * 3),
        ('op_size', ctypes.c_uint8),
        ('addr_size', ctypes.c_uint8),
        ('disp_size', ctypes.c_uint8),
        ('imm_size', ctypes.c_uint8),
        ('modrm', ctypes.c_uint8),
        ('sib', ctypes.c_uint8),
        ('disp', ctypes.c_int32),
        ('sib_index', ctypes.c_uint),
        ('sib_scale', ctypes.c_int8),
        ('sib_base', ctypes.c_uint),
        ('op_count', ctypes.c_uint8),
        ('op_info', x86_op * 8),
    )

def get_arch_info(a):
    op_info = []
    for i in a.op_info:
        if i.type == 0:
            break
        op_info.append(i)
    return (a.prefix, a.segment, a.opcode, a.op_size, a.addr_size, a.disp_size, a.imm_size, a.modrm, a.sib, a.disp, a.sib_index, a.sib_scale, op_info)

# all Intel reigsters
X86_REG_INVALID = 0
X86_REG_AH = 1
X86_REG_AL = 2
X86_REG_AX = 3
X86_REG_BH = 4
X86_REG_BL = 5
X86_REG_BP = 6
X86_REG_BPL = 7
X86_REG_BX = 8
X86_REG_CH = 9
X86_REG_CL = 10
X86_REG_CS = 11
X86_REG_CX = 12
X86_REG_DH = 13
X86_REG_DI = 14
X86_REG_DIL = 15
X86_REG_DL = 16
X86_REG_DS = 17
X86_REG_DX = 18
X86_REG_EAX = 19
X86_REG_EBP = 20
X86_REG_EBX = 21
X86_REG_ECX = 22
X86_REG_EDI = 23
X86_REG_EDX = 24
X86_REG_FLAGS = 25
X86_REG_EIP = 26
X86_REG_EIZ = 27
X86_REG_ES = 28
X86_REG_ESI = 29
X86_REG_ESP = 30
X86_REG_FPSW = 31
X86_REG_FS = 32
X86_REG_GS = 33
X86_REG_IP = 34
X86_REG_RAX = 35
X86_REG_RBP = 36
X86_REG_RBX = 37
X86_REG_RCX = 38
X86_REG_RDI = 39
X86_REG_RDX = 40
X86_REG_RIP = 41
X86_REG_RIZ = 42
X86_REG_RSI = 43
X86_REG_RSP = 44
X86_REG_SI = 45
X86_REG_SIL = 46
X86_REG_SP = 47
X86_REG_SPL = 48
X86_REG_SS = 49
X86_REG_CR0 = 50
X86_REG_CR1 = 51
X86_REG_CR2 = 52
X86_REG_CR3 = 53
X86_REG_CR4 = 54
X86_REG_CR5 = 55
X86_REG_CR6 = 56
X86_REG_CR7 = 57
X86_REG_CR8 = 58
X86_REG_CR9 = 59
X86_REG_CR10 = 60
X86_REG_CR11 = 61
X86_REG_CR12 = 62
X86_REG_CR13 = 63
X86_REG_CR14 = 64
X86_REG_CR15 = 65
X86_REG_DR0 = 66
X86_REG_DR1 = 67
X86_REG_DR2 = 68
X86_REG_DR3 = 69
X86_REG_DR4 = 70
X86_REG_DR5 = 71
X86_REG_DR6 = 72
X86_REG_DR7 = 73
X86_REG_FP0 = 74
X86_REG_FP1 = 75
X86_REG_FP2 = 76
X86_REG_FP3 = 77
X86_REG_FP4 = 78
X86_REG_FP5 = 79
X86_REG_FP6 = 80
X86_REG_K0 = 81
X86_REG_K1 = 82
X86_REG_K2 = 83
X86_REG_K3 = 84
X86_REG_K4 = 85
X86_REG_K5 = 86
X86_REG_K6 = 87
X86_REG_K7 = 88
X86_REG_MM0 = 89
X86_REG_MM1 = 90
X86_REG_MM2 = 91
X86_REG_MM3 = 92
X86_REG_MM4 = 93
X86_REG_MM5 = 94
X86_REG_MM6 = 95
X86_REG_MM7 = 96
X86_REG_R8 = 97
X86_REG_R9 = 98
X86_REG_R10 = 99
X86_REG_R11 = 100
X86_REG_R12 = 101
X86_REG_R13 = 102
X86_REG_R14 = 103
X86_REG_R15 = 104
X86_REG_ST0 = 105
X86_REG_ST1 = 106
X86_REG_ST2 = 107
X86_REG_ST3 = 108
X86_REG_ST4 = 109
X86_REG_ST5 = 110
X86_REG_ST6 = 111
X86_REG_ST7 = 112
X86_REG_XMM0 = 113
X86_REG_XMM1 = 114
X86_REG_XMM2 = 115
X86_REG_XMM3 = 116
X86_REG_XMM4 = 117
X86_REG_XMM5 = 118
X86_REG_XMM6 = 119
X86_REG_XMM7 = 120
X86_REG_XMM8 = 121
X86_REG_XMM9 = 122
X86_REG_XMM10 = 123
X86_REG_XMM11 = 124
X86_REG_XMM12 = 125
X86_REG_XMM13 = 126
X86_REG_XMM14 = 127
X86_REG_XMM15 = 128
X86_REG_XMM16 = 129
X86_REG_XMM17 = 130
X86_REG_XMM18 = 131
X86_REG_XMM19 = 132
X86_REG_XMM20 = 133
X86_REG_XMM21 = 134
X86_REG_XMM22 = 135
X86_REG_XMM23 = 136
X86_REG_XMM24 = 137
X86_REG_XMM25 = 138
X86_REG_XMM26 = 139
X86_REG_XMM27 = 140
X86_REG_XMM28 = 141
X86_REG_XMM29 = 142
X86_REG_XMM30 = 143
X86_REG_XMM31 = 144
X86_REG_YMM0 = 145
X86_REG_YMM1 = 146
X86_REG_YMM2 = 147
X86_REG_YMM3 = 148
X86_REG_YMM4 = 149
X86_REG_YMM5 = 150
X86_REG_YMM6 = 151
X86_REG_YMM7 = 152
X86_REG_YMM8 = 153
X86_REG_YMM9 = 154
X86_REG_YMM10 = 155
X86_REG_YMM11 = 156
X86_REG_YMM12 = 157
X86_REG_YMM13 = 158
X86_REG_YMM14 = 159
X86_REG_YMM15 = 160
X86_REG_YMM16 = 161
X86_REG_YMM17 = 162
X86_REG_YMM18 = 163
X86_REG_YMM19 = 164
X86_REG_YMM20 = 165
X86_REG_YMM21 = 166
X86_REG_YMM22 = 167
X86_REG_YMM23 = 168
X86_REG_YMM24 = 169
X86_REG_YMM25 = 170
X86_REG_YMM26 = 171
X86_REG_YMM27 = 172
X86_REG_YMM28 = 173
X86_REG_YMM29 = 174
X86_REG_YMM30 = 175
X86_REG_YMM31 = 176
X86_REG_ZMM0 = 177
X86_REG_ZMM1 = 178
X86_REG_ZMM2 = 179
X86_REG_ZMM3 = 180
X86_REG_ZMM4 = 181
X86_REG_ZMM5 = 182
X86_REG_ZMM6 = 183
X86_REG_ZMM7 = 184
X86_REG_ZMM8 = 185
X86_REG_ZMM9 = 186
X86_REG_ZMM10 = 187
X86_REG_ZMM11 = 188
X86_REG_ZMM12 = 189
X86_REG_ZMM13 = 190
X86_REG_ZMM14 = 191
X86_REG_ZMM15 = 192
X86_REG_ZMM16 = 193
X86_REG_ZMM17 = 194
X86_REG_ZMM18 = 195
X86_REG_ZMM19 = 196
X86_REG_ZMM20 = 197
X86_REG_ZMM21 = 198
X86_REG_ZMM22 = 199
X86_REG_ZMM23 = 200
X86_REG_ZMM24 = 201
X86_REG_ZMM25 = 202
X86_REG_ZMM26 = 203
X86_REG_ZMM27 = 204
X86_REG_ZMM28 = 205
X86_REG_ZMM29 = 206
X86_REG_ZMM30 = 207
X86_REG_ZMM31 = 208
X86_REG_R8B = 209
X86_REG_R9B = 210
X86_REG_R10B = 211
X86_REG_R11B = 212
X86_REG_R12B = 213
X86_REG_R13B = 214
X86_REG_R14B = 215
X86_REG_R15B = 216
X86_REG_R8D = 217
X86_REG_R9D = 218
X86_REG_R10D = 219
X86_REG_R11D = 220
X86_REG_R12D = 221
X86_REG_R13D = 222
X86_REG_R14D = 223
X86_REG_R15D = 224
X86_REG_R8W = 225
X86_REG_R9W = 226
X86_REG_R10W = 227
X86_REG_R11W = 228
X86_REG_R12W = 229
X86_REG_R13W = 230
X86_REG_R14W = 231
X86_REG_R15W = 232

# all Intel instructions
X86_INS_INVALID = 0
X86_INS_AAA = 1
X86_INS_AAD = 2
X86_INS_AAM = 3
X86_INS_AAS = 4
X86_INS_FABS = 5
X86_INS_ADC = 6
X86_INS_ADCX = 7
X86_INS_ADD = 8
X86_INS_ADDPD = 9
X86_INS_ADDPS = 10
X86_INS_ADDSD = 11
X86_INS_ADDSS = 12
X86_INS_ADDSUBPD = 13
X86_INS_ADDSUBPS = 14
X86_INS_FADD = 15
X86_INS_FIADD = 16
X86_INS_FADDP = 17
X86_INS_ADOX = 18
X86_INS_AESDECLAST = 19
X86_INS_AESDEC = 20
X86_INS_AESENCLAST = 21
X86_INS_AESENC = 22
X86_INS_AESIMC = 23
X86_INS_AESKEYGENASSIST = 24
X86_INS_AND = 25
X86_INS_ANDN = 26
X86_INS_ANDNPD = 27
X86_INS_ANDNPS = 28
X86_INS_ANDPD = 29
X86_INS_ANDPS = 30
X86_INS_ARPL = 31
X86_INS_BEXTR = 32
X86_INS_BLENDPD = 33
X86_INS_BLENDPS = 34
X86_INS_BLENDVPD = 35
X86_INS_BLENDVPS = 36
X86_INS_BLSI = 37
X86_INS_BLSMSK = 38
X86_INS_BLSR = 39
X86_INS_BOUND = 40
X86_INS_BSF = 41
X86_INS_BSR = 42
X86_INS_BSWAP = 43
X86_INS_BT = 44
X86_INS_BTC = 45
X86_INS_BTR = 46
X86_INS_BTS = 47
X86_INS_BZHI = 48
X86_INS_CALL = 49
X86_INS_CALLW = 50
X86_INS_CBW = 51
X86_INS_CDQ = 52
X86_INS_CDQE = 53
X86_INS_FCHS = 54
X86_INS_CLAC = 55
X86_INS_CLC = 56
X86_INS_CLD = 57
X86_INS_CLFLUSH = 58
X86_INS_CLGI = 59
X86_INS_CLI = 60
X86_INS_CLTS = 61
X86_INS_CMC = 62
X86_INS_CMOVA = 63
X86_INS_CMOVAE = 64
X86_INS_CMOVB = 65
X86_INS_CMOVBE = 66
X86_INS_FCMOVBE = 67
X86_INS_FCMOVB = 68
X86_INS_CMOVE = 69
X86_INS_FCMOVE = 70
X86_INS_CMOVG = 71
X86_INS_CMOVGE = 72
X86_INS_CMOVL = 73
X86_INS_CMOVLE = 74
X86_INS_FCMOVNBE = 75
X86_INS_FCMOVNB = 76
X86_INS_CMOVNE = 77
X86_INS_FCMOVNE = 78
X86_INS_CMOVNO = 79
X86_INS_CMOVNP = 80
X86_INS_FCMOVNU = 81
X86_INS_CMOVNS = 82
X86_INS_CMOVO = 83
X86_INS_CMOVP = 84
X86_INS_FCMOVU = 85
X86_INS_CMOVS = 86
X86_INS_CMP = 87
X86_INS_CMPPD = 88
X86_INS_CMPPS = 89
X86_INS_CMPSW = 90
X86_INS_CMPSD = 91
X86_INS_CMPSQ = 92
X86_INS_CMPSB = 93
X86_INS_CMPSS = 94
X86_INS_CMPXCHG16B = 95
X86_INS_CMPXCHG = 96
X86_INS_CMPXCHG8B = 97
X86_INS_COMISD = 98
X86_INS_COMISS = 99
X86_INS_FCOMP = 100
X86_INS_FCOMPI = 101
X86_INS_FCOMI = 102
X86_INS_FCOM = 103
X86_INS_FCOS = 104
X86_INS_CPUID = 105
X86_INS_CQO = 106
X86_INS_CRC32 = 107
X86_INS_CS = 108
X86_INS_CVTDQ2PD = 109
X86_INS_CVTDQ2PS = 110
X86_INS_CVTPD2DQ = 111
X86_INS_CVTPD2PS = 112
X86_INS_CVTPS2DQ = 113
X86_INS_CVTPS2PD = 114
X86_INS_CVTSD2SI = 115
X86_INS_CVTSD2SS = 116
X86_INS_CVTSI2SD = 117
X86_INS_CVTSI2SS = 118
X86_INS_CVTSS2SD = 119
X86_INS_CVTSS2SI = 120
X86_INS_CVTTPD2DQ = 121
X86_INS_CVTTPS2DQ = 122
X86_INS_CVTTSD2SI = 123
X86_INS_CVTTSS2SI = 124
X86_INS_CWD = 125
X86_INS_CWDE = 126
X86_INS_DAA = 127
X86_INS_DAS = 128
X86_INS_DATA16 = 129
X86_INS_DEC = 130
X86_INS_DIV = 131
X86_INS_DIVPD = 132
X86_INS_DIVPS = 133
X86_INS_FDIVR = 134
X86_INS_FIDIVR = 135
X86_INS_FDIVRP = 136
X86_INS_DIVSD = 137
X86_INS_DIVSS = 138
X86_INS_FDIV = 139
X86_INS_FIDIV = 140
X86_INS_FDIVP = 141
X86_INS_DPPD = 142
X86_INS_DPPS = 143
X86_INS_DS = 144
X86_INS_RET = 145
X86_INS_ENTER = 146
X86_INS_ES = 147
X86_INS_EXTRACTPS = 148
X86_INS_EXTRQ = 149
X86_INS_F2XM1 = 150
X86_INS_LCALL = 151
X86_INS_LJMP = 152
X86_INS_FBLD = 153
X86_INS_FBSTP = 154
X86_INS_FCOMPP = 155
X86_INS_FDECSTP = 156
X86_INS_FEMMS = 157
X86_INS_FFREE = 158
X86_INS_FICOM = 159
X86_INS_FICOMP = 160
X86_INS_FINCSTP = 161
X86_INS_FLDCW = 162
X86_INS_FLDENV = 163
X86_INS_FLDL2E = 164
X86_INS_FLDL2T = 165
X86_INS_FLDLG2 = 166
X86_INS_FLDLN2 = 167
X86_INS_FLDPI = 168
X86_INS_FNCLEX = 169
X86_INS_FNINIT = 170
X86_INS_FNOP = 171
X86_INS_FNSTCW = 172
X86_INS_FNSTSW = 173
X86_INS_FPATAN = 174
X86_INS_FPREM = 175
X86_INS_FPREM1 = 176
X86_INS_FPTAN = 177
X86_INS_FRNDINT = 178
X86_INS_FRSTOR = 179
X86_INS_FNSAVE = 180
X86_INS_FSCALE = 181
X86_INS_FSINCOS = 182
X86_INS_FNSTENV = 183
X86_INS_FS = 184
X86_INS_FXAM = 185
X86_INS_FXRSTOR = 186
X86_INS_FXRSTORQ = 187
X86_INS_FXSAVE = 188
X86_INS_FXSAVEQ = 189
X86_INS_FXTRACT = 190
X86_INS_FYL2X = 191
X86_INS_FYL2XP1 = 192
X86_INS_MOVAPD = 193
X86_INS_MOVAPS = 194
X86_INS_ORPD = 195
X86_INS_ORPS = 196
X86_INS_VMOVAPD = 197
X86_INS_VMOVAPS = 198
X86_INS_XORPD = 199
X86_INS_XORPS = 200
X86_INS_GS = 201
X86_INS_HADDPD = 202
X86_INS_HADDPS = 203
X86_INS_HLT = 204
X86_INS_HSUBPD = 205
X86_INS_HSUBPS = 206
X86_INS_IDIV = 207
X86_INS_FILD = 208
X86_INS_IMUL = 209
X86_INS_INS = 210
X86_INS_IN = 211
X86_INS_INC = 212
X86_INS_INSERTPS = 213
X86_INS_INSERTQ = 214
X86_INS_INT = 215
X86_INS_INT3 = 216
X86_INS_INTO = 217
X86_INS_INVD = 218
X86_INS_INVEPT = 219
X86_INS_INVLPG = 220
X86_INS_INVLPGA = 221
X86_INS_INVPCID = 222
X86_INS_INVVPID = 223
X86_INS_IRET = 224
X86_INS_IRETD = 225
X86_INS_IRETQ = 226
X86_INS_FISTTP = 227
X86_INS_FIST = 228
X86_INS_FISTP = 229
X86_INS_UCOMISD = 230
X86_INS_UCOMISS = 231
X86_INS_VCMPSD = 232
X86_INS_VCMPSS = 233
X86_INS_VCOMISD = 234
X86_INS_VCOMISS = 235
X86_INS_VCVTSD2SS = 236
X86_INS_VCVTSI2SD = 237
X86_INS_VCVTSI2SS = 238
X86_INS_VCVTSS2SD = 239
X86_INS_VCVTTSD2SI = 240
X86_INS_VCVTTSS2SI = 241
X86_INS_VUCOMISD = 242
X86_INS_VUCOMISS = 243
X86_INS_JAE = 244
X86_INS_JA = 245
X86_INS_JBE = 246
X86_INS_JB = 247
X86_INS_JCXZ = 248
X86_INS_JECXZ = 249
X86_INS_JE = 250
X86_INS_JGE = 251
X86_INS_JG = 252
X86_INS_JLE = 253
X86_INS_JL = 254
X86_INS_JMP = 255
X86_INS_JMPQ = 256
X86_INS_JNE = 257
X86_INS_JNO = 258
X86_INS_JNP = 259
X86_INS_JNS = 260
X86_INS_JO = 261
X86_INS_JP = 262
X86_INS_JRCXZ = 263
X86_INS_JS = 264
X86_INS_KADDW = 265
X86_INS_KANDNW = 266
X86_INS_KANDW = 267
X86_INS_KMOVW = 268
X86_INS_KNOTW = 269
X86_INS_KORTESTW = 270
X86_INS_KORW = 271
X86_INS_KSHIFTLW = 272
X86_INS_KSHIFTRW = 273
X86_INS_KTESTW = 274
X86_INS_KUNPCKBW = 275
X86_INS_KXNORW = 276
X86_INS_KXORW = 277
X86_INS_LAHF = 278
X86_INS_LAR = 279
X86_INS_LDDQU = 280
X86_INS_LDMXCSR = 281
X86_INS_LDS = 282
X86_INS_FLDZ = 283
X86_INS_FLD1 = 284
X86_INS_FLD = 285
X86_INS_LEA = 286
X86_INS_LEAVE = 287
X86_INS_LES = 288
X86_INS_LFENCE = 289
X86_INS_LFS = 290
X86_INS_LGDT = 291
X86_INS_LGS = 292
X86_INS_LIDT = 293
X86_INS_LLDT = 294
X86_INS_LMSW = 295
X86_INS_OR = 296
X86_INS_LOCK = 297
X86_INS_SUB = 298
X86_INS_XOR = 299
X86_INS_LODSB = 300
X86_INS_LODSD = 301
X86_INS_LODSQ = 302
X86_INS_LODSW = 303
X86_INS_LOOP = 304
X86_INS_LOOPE = 305
X86_INS_LOOPNE = 306
X86_INS_RETF = 307
X86_INS_LSL = 308
X86_INS_LSS = 309
X86_INS_LTR = 310
X86_INS_XADD = 311
X86_INS_LZCNT = 312
X86_INS_MASKMOVDQU = 313
X86_INS_MAXPD = 314
X86_INS_MAXPS = 315
X86_INS_MAXSD = 316
X86_INS_MAXSS = 317
X86_INS_MFENCE = 318
X86_INS_MINPD = 319
X86_INS_MINPS = 320
X86_INS_MINSD = 321
X86_INS_MINSS = 322
X86_INS_CVTPD2PI = 323
X86_INS_CVTPI2PD = 324
X86_INS_CVTPI2PS = 325
X86_INS_CVTPS2PI = 326
X86_INS_CVTTPD2PI = 327
X86_INS_CVTTPS2PI = 328
X86_INS_EMMS = 329
X86_INS_MASKMOVQ = 330
X86_INS_MOVD = 331
X86_INS_MOVDQ2Q = 332
X86_INS_MOVNTQ = 333
X86_INS_MOVQ2DQ = 334
X86_INS_MOVQ = 335
X86_INS_PABSB = 336
X86_INS_PABSD = 337
X86_INS_PABSW = 338
X86_INS_PACKSSDW = 339
X86_INS_PACKSSWB = 340
X86_INS_PACKUSWB = 341
X86_INS_PADDB = 342
X86_INS_PADDD = 343
X86_INS_PADDQ = 344
X86_INS_PADDSB = 345
X86_INS_PADDSW = 346
X86_INS_PADDUSB = 347
X86_INS_PADDUSW = 348
X86_INS_PADDW = 349
X86_INS_PALIGNR = 350
X86_INS_PANDN = 351
X86_INS_PAND = 352
X86_INS_PAVGB = 353
X86_INS_PAVGW = 354
X86_INS_PCMPEQB = 355
X86_INS_PCMPEQD = 356
X86_INS_PCMPEQW = 357
X86_INS_PCMPGTB = 358
X86_INS_PCMPGTD = 359
X86_INS_PCMPGTW = 360
X86_INS_PEXTRW = 361
X86_INS_PHADDSW = 362
X86_INS_PHADDW = 363
X86_INS_PHADDD = 364
X86_INS_PHSUBD = 365
X86_INS_PHSUBSW = 366
X86_INS_PHSUBW = 367
X86_INS_PINSRW = 368
X86_INS_PMADDUBSW = 369
X86_INS_PMADDWD = 370
X86_INS_PMAXSW = 371
X86_INS_PMAXUB = 372
X86_INS_PMINSW = 373
X86_INS_PMINUB = 374
X86_INS_PMOVMSKB = 375
X86_INS_PMULHRSW = 376
X86_INS_PMULHUW = 377
X86_INS_PMULHW = 378
X86_INS_PMULLW = 379
X86_INS_PMULUDQ = 380
X86_INS_POR = 381
X86_INS_PSADBW = 382
X86_INS_PSHUFB = 383
X86_INS_PSHUFW = 384
X86_INS_PSIGNB = 385
X86_INS_PSIGND = 386
X86_INS_PSIGNW = 387
X86_INS_PSLLD = 388
X86_INS_PSLLQ = 389
X86_INS_PSLLW = 390
X86_INS_PSRAD = 391
X86_INS_PSRAW = 392
X86_INS_PSRLD = 393
X86_INS_PSRLQ = 394
X86_INS_PSRLW = 395
X86_INS_PSUBB = 396
X86_INS_PSUBD = 397
X86_INS_PSUBQ = 398
X86_INS_PSUBSB = 399
X86_INS_PSUBSW = 400
X86_INS_PSUBUSB = 401
X86_INS_PSUBUSW = 402
X86_INS_PSUBW = 403
X86_INS_PUNPCKHBW = 404
X86_INS_PUNPCKHDQ = 405
X86_INS_PUNPCKHWD = 406
X86_INS_PUNPCKLBW = 407
X86_INS_PUNPCKLDQ = 408
X86_INS_PUNPCKLWD = 409
X86_INS_PXOR = 410
X86_INS_MONITOR = 411
X86_INS_MONTMUL = 412
X86_INS_MOV = 413
X86_INS_MOVABS = 414
X86_INS_MOVBE = 415
X86_INS_MOVDDUP = 416
X86_INS_MOVDQA = 417
X86_INS_MOVDQU = 418
X86_INS_MOVHLPS = 419
X86_INS_MOVHPD = 420
X86_INS_MOVHPS = 421
X86_INS_MOVLHPS = 422
X86_INS_MOVLPD = 423
X86_INS_MOVLPS = 424
X86_INS_MOVMSKPD = 425
X86_INS_MOVMSKPS = 426
X86_INS_MOVNTDQA = 427
X86_INS_MOVNTDQ = 428
X86_INS_MOVNTI = 429
X86_INS_MOVNTPD = 430
X86_INS_MOVNTPS = 431
X86_INS_MOVNTSD = 432
X86_INS_MOVNTSS = 433
X86_INS_MOVSB = 434
X86_INS_MOVSD = 435
X86_INS_MOVSHDUP = 436
X86_INS_MOVSLDUP = 437
X86_INS_MOVSQ = 438
X86_INS_MOVSS = 439
X86_INS_MOVSW = 440
X86_INS_MOVSX = 441
X86_INS_MOVSXD = 442
X86_INS_MOVUPD = 443
X86_INS_MOVUPS = 444
X86_INS_MOVZX = 445
X86_INS_MPSADBW = 446
X86_INS_MUL = 447
X86_INS_MULPD = 448
X86_INS_MULPS = 449
X86_INS_MULSD = 450
X86_INS_MULSS = 451
X86_INS_MULX = 452
X86_INS_FMUL = 453
X86_INS_FIMUL = 454
X86_INS_FMULP = 455
X86_INS_MWAIT = 456
X86_INS_NEG = 457
X86_INS_NOP = 458
X86_INS_NOT = 459
X86_INS_OUT = 460
X86_INS_OUTSB = 461
X86_INS_OUTSD = 462
X86_INS_OUTSW = 463
X86_INS_PACKUSDW = 464
X86_INS_PAUSE = 465
X86_INS_PAVGUSB = 466
X86_INS_PBLENDVB = 467
X86_INS_PBLENDW = 468
X86_INS_PCLMULQDQ = 469
X86_INS_PCMPEQQ = 470
X86_INS_PCMPESTRI = 471
X86_INS_PCMPESTRM = 472
X86_INS_PCMPGTQ = 473
X86_INS_PCMPISTRI = 474
X86_INS_PCMPISTRM = 475
X86_INS_PDEP = 476
X86_INS_PEXT = 477
X86_INS_PEXTRB = 478
X86_INS_PEXTRD = 479
X86_INS_PEXTRQ = 480
X86_INS_PF2ID = 481
X86_INS_PF2IW = 482
X86_INS_PFACC = 483
X86_INS_PFADD = 484
X86_INS_PFCMPEQ = 485
X86_INS_PFCMPGE = 486
X86_INS_PFCMPGT = 487
X86_INS_PFMAX = 488
X86_INS_PFMIN = 489
X86_INS_PFMUL = 490
X86_INS_PFNACC = 491
X86_INS_PFPNACC = 492
X86_INS_PFRCPIT1 = 493
X86_INS_PFRCPIT2 = 494
X86_INS_PFRCP = 495
X86_INS_PFRSQIT1 = 496
X86_INS_PFRSQRT = 497
X86_INS_PFSUBR = 498
X86_INS_PFSUB = 499
X86_INS_PHMINPOSUW = 500
X86_INS_PI2FD = 501
X86_INS_PI2FW = 502
X86_INS_PINSRB = 503
X86_INS_PINSRD = 504
X86_INS_PINSRQ = 505
X86_INS_PMAXSB = 506
X86_INS_PMAXSD = 507
X86_INS_PMAXUD = 508
X86_INS_PMAXUW = 509
X86_INS_PMINSB = 510
X86_INS_PMINSD = 511
X86_INS_PMINUD = 512
X86_INS_PMINUW = 513
X86_INS_PMOVSXBD = 514
X86_INS_PMOVSXBQ = 515
X86_INS_PMOVSXBW = 516
X86_INS_PMOVSXDQ = 517
X86_INS_PMOVSXWD = 518
X86_INS_PMOVSXWQ = 519
X86_INS_PMOVZXBD = 520
X86_INS_PMOVZXBQ = 521
X86_INS_PMOVZXBW = 522
X86_INS_PMOVZXDQ = 523
X86_INS_PMOVZXWD = 524
X86_INS_PMOVZXWQ = 525
X86_INS_PMULDQ = 526
X86_INS_PMULHRW = 527
X86_INS_PMULLD = 528
X86_INS_POP = 529
X86_INS_POPA = 530
X86_INS_POPCNT = 531
X86_INS_POPF = 532
X86_INS_POPFD = 533
X86_INS_POPFQ = 534
X86_INS_PREFETCH = 535
X86_INS_PREFETCHNTA = 536
X86_INS_PREFETCHT0 = 537
X86_INS_PREFETCHT1 = 538
X86_INS_PREFETCHT2 = 539
X86_INS_PREFETCHW = 540
X86_INS_PSHUFD = 541
X86_INS_PSHUFHW = 542
X86_INS_PSHUFLW = 543
X86_INS_PSLLDQ = 544
X86_INS_PSRLDQ = 545
X86_INS_PSWAPD = 546
X86_INS_PTEST = 547
X86_INS_PUNPCKHQDQ = 548
X86_INS_PUNPCKLQDQ = 549
X86_INS_PUSH = 550
X86_INS_PUSHA = 551
X86_INS_PUSHF = 552
X86_INS_PUSHFD = 553
X86_INS_PUSHFQ = 554
X86_INS_RCL = 555
X86_INS_RCPPS = 556
X86_INS_RCPSS = 557
X86_INS_RCR = 558
X86_INS_RDFSBASE = 559
X86_INS_RDGSBASE = 560
X86_INS_RDMSR = 561
X86_INS_RDPMC = 562
X86_INS_RDRAND = 563
X86_INS_RDSEED = 564
X86_INS_RDTSC = 565
X86_INS_RDTSCP = 566
X86_INS_REPNE = 567
X86_INS_REP = 568
X86_INS_REX64 = 569
X86_INS_ROL = 570
X86_INS_ROR = 571
X86_INS_RORX = 572
X86_INS_ROUNDPD = 573
X86_INS_ROUNDPS = 574
X86_INS_ROUNDSD = 575
X86_INS_ROUNDSS = 576
X86_INS_RSM = 577
X86_INS_RSQRTPS = 578
X86_INS_RSQRTSS = 579
X86_INS_SAHF = 580
X86_INS_SAR = 581
X86_INS_SARX = 582
X86_INS_SBB = 583
X86_INS_SCASW = 584
X86_INS_SCASD = 585
X86_INS_SCASQ = 586
X86_INS_SCASB = 587
X86_INS_SETAE = 588
X86_INS_SETA = 589
X86_INS_SETBE = 590
X86_INS_SETB = 591
X86_INS_SETE = 592
X86_INS_SETGE = 593
X86_INS_SETG = 594
X86_INS_SETLE = 595
X86_INS_SETL = 596
X86_INS_SETNE = 597
X86_INS_SETNO = 598
X86_INS_SETNP = 599
X86_INS_SETNS = 600
X86_INS_SETO = 601
X86_INS_SETP = 602
X86_INS_SETS = 603
X86_INS_SFENCE = 604
X86_INS_SGDT = 605
X86_INS_SHA1MSG1 = 606
X86_INS_SHA1MSG2 = 607
X86_INS_SHA1NEXTE = 608
X86_INS_SHA1RNDS4 = 609
X86_INS_SHA256MSG1 = 610
X86_INS_SHA256MSG2 = 611
X86_INS_SHA256RNDS2 = 612
X86_INS_SHL = 613
X86_INS_SHLD = 614
X86_INS_SHLX = 615
X86_INS_SHR = 616
X86_INS_SHRD = 617
X86_INS_SHRX = 618
X86_INS_SHUFPD = 619
X86_INS_SHUFPS = 620
X86_INS_SIDT = 621
X86_INS_FSIN = 622
X86_INS_SKINIT = 623
X86_INS_SLDT = 624
X86_INS_SMSW = 625
X86_INS_SQRTPD = 626
X86_INS_SQRTPS = 627
X86_INS_SQRTSD = 628
X86_INS_SQRTSS = 629
X86_INS_FSQRT = 630
X86_INS_SS = 631
X86_INS_STAC = 632
X86_INS_STC = 633
X86_INS_STD = 634
X86_INS_STGI = 635
X86_INS_STI = 636
X86_INS_STMXCSR = 637
X86_INS_STOSB = 638
X86_INS_STOSD = 639
X86_INS_STOSQ = 640
X86_INS_STOSW = 641
X86_INS_STR = 642
X86_INS_FST = 643
X86_INS_FSTP = 644
X86_INS_SUBPD = 645
X86_INS_SUBPS = 646
X86_INS_FSUBR = 647
X86_INS_FISUBR = 648
X86_INS_FSUBRP = 649
X86_INS_SUBSD = 650
X86_INS_SUBSS = 651
X86_INS_FSUB = 652
X86_INS_FISUB = 653
X86_INS_FSUBP = 654
X86_INS_SWAPGS = 655
X86_INS_SYSCALL = 656
X86_INS_SYSENTER = 657
X86_INS_SYSEXIT = 658
X86_INS_SYSRET = 659
X86_INS_TEST = 660
X86_INS_UD2 = 661
X86_INS_FTST = 662
X86_INS_TZCNT = 663
X86_INS_FUCOMPI = 664
X86_INS_FUCOMI = 665
X86_INS_FUCOMPP = 666
X86_INS_FUCOMP = 667
X86_INS_FUCOM = 668
X86_INS_UD2B = 669
X86_INS_UNPCKHPD = 670
X86_INS_UNPCKHPS = 671
X86_INS_UNPCKLPD = 672
X86_INS_UNPCKLPS = 673
X86_INS_VADDPD = 674
X86_INS_VADDPS = 675
X86_INS_VADDSD = 676
X86_INS_VADDSS = 677
X86_INS_VADDSUBPD = 678
X86_INS_VADDSUBPS = 679
X86_INS_VAESDECLAST = 680
X86_INS_VAESDEC = 681
X86_INS_VAESENCLAST = 682
X86_INS_VAESENC = 683
X86_INS_VAESIMC = 684
X86_INS_VAESKEYGENASSIST = 685
X86_INS_VALIGND = 686
X86_INS_VALIGNQ = 687
X86_INS_VANDNPD = 688
X86_INS_VANDNPS = 689
X86_INS_VANDPD = 690
X86_INS_VANDPS = 691
X86_INS_VBLENDMPD = 692
X86_INS_VBLENDMPS = 693
X86_INS_VBLENDPD = 694
X86_INS_VBLENDPS = 695
X86_INS_VBLENDVPD = 696
X86_INS_VBLENDVPS = 697
X86_INS_VBROADCASTF128 = 698
X86_INS_VBROADCASTI128 = 699
X86_INS_VBROADCASTSD = 700
X86_INS_VBROADCASTSS = 701
X86_INS_VCMPPD = 702
X86_INS_VVCMPPD = 703
X86_INS_VCMPPS = 704
X86_INS_VVCMPPS = 705
X86_INS_VCVTDQ2PD = 706
X86_INS_VCVTDQ2PS = 707
X86_INS_VCVTPD2DQX = 708
X86_INS_VCVTPD2DQ = 709
X86_INS_VCVTPD2PSX = 710
X86_INS_VCVTPD2PS = 711
X86_INS_VCVTPH2PS = 712
X86_INS_VCVTPS2DQ = 713
X86_INS_VCVTPS2PD = 714
X86_INS_VCVTPS2PH = 715
X86_INS_VCVTSD2SI = 716
X86_INS_VCVTSS2SI = 717
X86_INS_VCVTTPD2DQX = 718
X86_INS_VCVTTPD2DQ = 719
X86_INS_VCVTTPD2UDQ = 720
X86_INS_VCVTTPS2DQ = 721
X86_INS_VCVTTPS2UDQ = 722
X86_INS_VCVTUDQ2PD = 723
X86_INS_VCVTUDQ2PS = 724
X86_INS_VDIVPD = 725
X86_INS_VDIVPS = 726
X86_INS_VDIVSD = 727
X86_INS_VDIVSS = 728
X86_INS_VDPPD = 729
X86_INS_VDPPS = 730
X86_INS_VERR = 731
X86_INS_VERW = 732
X86_INS_VEXTRACTF128 = 733
X86_INS_VEXTRACTF32X4 = 734
X86_INS_VEXTRACTF64X4 = 735
X86_INS_VEXTRACTI128 = 736
X86_INS_VEXTRACTI32X4 = 737
X86_INS_VEXTRACTI64X4 = 738
X86_INS_VEXTRACTPS = 739
X86_INS_VFMADD132PD = 740
X86_INS_VFMADD132PS = 741
X86_INS_VFMADD213PD = 742
X86_INS_VFMADD213PS = 743
X86_INS_VFMADDPD = 744
X86_INS_VFMADD231PD = 745
X86_INS_VFMADDPS = 746
X86_INS_VFMADD231PS = 747
X86_INS_VFMADDSD = 748
X86_INS_VFMADD213SD = 749
X86_INS_VFMADD132SD = 750
X86_INS_VFMADD231SD = 751
X86_INS_VFMADDSS = 752
X86_INS_VFMADD213SS = 753
X86_INS_VFMADD132SS = 754
X86_INS_VFMADD231SS = 755
X86_INS_VFMADDSUB132PD = 756
X86_INS_VFMADDSUB132PS = 757
X86_INS_VFMADDSUB213PD = 758
X86_INS_VFMADDSUB213PS = 759
X86_INS_VFMADDSUBPD = 760
X86_INS_VFMADDSUB231PD = 761
X86_INS_VFMADDSUBPS = 762
X86_INS_VFMADDSUB231PS = 763
X86_INS_VFMSUB132PD = 764
X86_INS_VFMSUB132PS = 765
X86_INS_VFMSUB213PD = 766
X86_INS_VFMSUB213PS = 767
X86_INS_VFMSUBADD132PD = 768
X86_INS_VFMSUBADD132PS = 769
X86_INS_VFMSUBADD213PD = 770
X86_INS_VFMSUBADD213PS = 771
X86_INS_VFMSUBADDPD = 772
X86_INS_VFMSUBADD231PD = 773
X86_INS_VFMSUBADDPS = 774
X86_INS_VFMSUBADD231PS = 775
X86_INS_VFMSUBPD = 776
X86_INS_VFMSUB231PD = 777
X86_INS_VFMSUBPS = 778
X86_INS_VFMSUB231PS = 779
X86_INS_VFMSUBSD = 780
X86_INS_VFMSUB213SD = 781
X86_INS_VFMSUB132SD = 782
X86_INS_VFMSUB231SD = 783
X86_INS_VFMSUBSS = 784
X86_INS_VFMSUB213SS = 785
X86_INS_VFMSUB132SS = 786
X86_INS_VFMSUB231SS = 787
X86_INS_VFNMADD132PD = 788
X86_INS_VFNMADD132PS = 789
X86_INS_VFNMADD213PD = 790
X86_INS_VFNMADD213PS = 791
X86_INS_VFNMADDPD = 792
X86_INS_VFNMADD231PD = 793
X86_INS_VFNMADDPS = 794
X86_INS_VFNMADD231PS = 795
X86_INS_VFNMADDSD = 796
X86_INS_VFNMADD213SD = 797
X86_INS_VFNMADD132SD = 798
X86_INS_VFNMADD231SD = 799
X86_INS_VFNMADDSS = 800
X86_INS_VFNMADD213SS = 801
X86_INS_VFNMADD132SS = 802
X86_INS_VFNMADD231SS = 803
X86_INS_VFNMSUB132PD = 804
X86_INS_VFNMSUB132PS = 805
X86_INS_VFNMSUB213PD = 806
X86_INS_VFNMSUB213PS = 807
X86_INS_VFNMSUBPD = 808
X86_INS_VFNMSUB231PD = 809
X86_INS_VFNMSUBPS = 810
X86_INS_VFNMSUB231PS = 811
X86_INS_VFNMSUBSD = 812
X86_INS_VFNMSUB213SD = 813
X86_INS_VFNMSUB132SD = 814
X86_INS_VFNMSUB231SD = 815
X86_INS_VFNMSUBSS = 816
X86_INS_VFNMSUB213SS = 817
X86_INS_VFNMSUB132SS = 818
X86_INS_VFNMSUB231SS = 819
X86_INS_VFRCZPD = 820
X86_INS_VFRCZPS = 821
X86_INS_VFRCZSD = 822
X86_INS_VFRCZSS = 823
X86_INS_VORPD = 824
X86_INS_VORPS = 825
X86_INS_VXORPD = 826
X86_INS_VXORPS = 827
X86_INS_VGATHERDPD = 828
X86_INS_VGATHERDPS = 829
X86_INS_VGATHERQPD = 830
X86_INS_VGATHERQPS = 831
X86_INS_VHADDPD = 832
X86_INS_VHADDPS = 833
X86_INS_VHSUBPD = 834
X86_INS_VHSUBPS = 835
X86_INS_VINSERTF128 = 836
X86_INS_VINSERTF32X4 = 837
X86_INS_VINSERTF64X4 = 838
X86_INS_VINSERTI128 = 839
X86_INS_VINSERTI32X4 = 840
X86_INS_VINSERTI64X4 = 841
X86_INS_VINSERTPS = 842
X86_INS_VLDDQU = 843
X86_INS_VLDMXCSR = 844
X86_INS_VMASKMOVDQU = 845
X86_INS_VMASKMOVPD = 846
X86_INS_VMASKMOVPS = 847
X86_INS_VMAXPD = 848
X86_INS_VMAXPS = 849
X86_INS_VMAXSD = 850
X86_INS_VMAXSS = 851
X86_INS_VMCALL = 852
X86_INS_VMCLEAR = 853
X86_INS_VMFUNC = 854
X86_INS_VMINPD = 855
X86_INS_VMINPS = 856
X86_INS_VMINSD = 857
X86_INS_VMINSS = 858
X86_INS_VMLAUNCH = 859
X86_INS_VMLOAD = 860
X86_INS_VMMCALL = 861
X86_INS_VMOVQ = 862
X86_INS_VVMOVQ = 863
X86_INS_VMOVDDUP = 864
X86_INS_VMOVD = 865
X86_INS_VMOVDQA32 = 866
X86_INS_VMOVDQA64 = 867
X86_INS_VMOVDQA = 868
X86_INS_VMOVDQU32 = 869
X86_INS_VMOVDQU64 = 870
X86_INS_VMOVDQU = 871
X86_INS_VMOVHLPS = 872
X86_INS_VMOVHPD = 873
X86_INS_VMOVHPS = 874
X86_INS_VMOVLHPS = 875
X86_INS_VMOVLPD = 876
X86_INS_VMOVLPS = 877
X86_INS_VMOVMSKPD = 878
X86_INS_VMOVMSKPS = 879
X86_INS_VMOVNTDQA = 880
X86_INS_VMOVNTDQ = 881
X86_INS_VMOVNTPD = 882
X86_INS_VMOVNTPS = 883
X86_INS_VMOVSD = 884
X86_INS_VMOVSHDUP = 885
X86_INS_VMOVSLDUP = 886
X86_INS_VMOVSS = 887
X86_INS_VMOVUPD = 888
X86_INS_VMOVUPS = 889
X86_INS_VMPSADBW = 890
X86_INS_VMPTRLD = 891
X86_INS_VMPTRST = 892
X86_INS_VMREAD = 893
X86_INS_VMRESUME = 894
X86_INS_VMRUN = 895
X86_INS_VMSAVE = 896
X86_INS_VMULPD = 897
X86_INS_VMULPS = 898
X86_INS_VMULSD = 899
X86_INS_VMULSS = 900
X86_INS_VMWRITE = 901
X86_INS_VMXOFF = 902
X86_INS_VMXON = 903
X86_INS_VPABSB = 904
X86_INS_VPABSD = 905
X86_INS_VPABSQ = 906
X86_INS_VPABSW = 907
X86_INS_VPACKSSDW = 908
X86_INS_VPACKSSWB = 909
X86_INS_VPACKUSDW = 910
X86_INS_VPACKUSWB = 911
X86_INS_VPADDB = 912
X86_INS_VPADDD = 913
X86_INS_VPADDQ = 914
X86_INS_VPADDSB = 915
X86_INS_VPADDSW = 916
X86_INS_VPADDUSB = 917
X86_INS_VPADDUSW = 918
X86_INS_VPADDW = 919
X86_INS_VPALIGNR = 920
X86_INS_VPANDD = 921
X86_INS_VPANDND = 922
X86_INS_VPANDNQ = 923
X86_INS_VPANDN = 924
X86_INS_VPANDQ = 925
X86_INS_VPAND = 926
X86_INS_VPAVGB = 927
X86_INS_VPAVGW = 928
X86_INS_VPBLENDD = 929
X86_INS_VPBLENDMD = 930
X86_INS_VPBLENDMQ = 931
X86_INS_VPBLENDVB = 932
X86_INS_VPBLENDW = 933
X86_INS_VPBROADCASTB = 934
X86_INS_VPBROADCASTD = 935
X86_INS_VPBROADCASTMB2Q = 936
X86_INS_VPBROADCASTMW2D = 937
X86_INS_VPBROADCASTQ = 938
X86_INS_VPBROADCASTW = 939
X86_INS_VPCLMULQDQ = 940
X86_INS_VPCMOV = 941
X86_INS_VPCMPD = 942
X86_INS_VPCMPEQB = 943
X86_INS_VPCMPEQD = 944
X86_INS_VPCMPEQQ = 945
X86_INS_VPCMPEQW = 946
X86_INS_VPCMPESTRI = 947
X86_INS_VPCMPESTRM = 948
X86_INS_VPCMPGTB = 949
X86_INS_VPCMPGTD = 950
X86_INS_VPCMPGTQ = 951
X86_INS_VPCMPGTW = 952
X86_INS_VPCMPISTRI = 953
X86_INS_VPCMPISTRM = 954
X86_INS_VPCMPQ = 955
X86_INS_VPCMPUD = 956
X86_INS_VPCMPUQ = 957
X86_INS_VPCOMB = 958
X86_INS_VPCOMD = 959
X86_INS_VPCOMQ = 960
X86_INS_VPCOMUB = 961
X86_INS_VPCOMUD = 962
X86_INS_VPCOMUQ = 963
X86_INS_VPCOMUW = 964
X86_INS_VPCOMW = 965
X86_INS_VPERM2F128 = 966
X86_INS_VPERM2I128 = 967
X86_INS_VPERMD = 968
X86_INS_VPERMI2D = 969
X86_INS_VPERMI2PD = 970
X86_INS_VPERMI2PS = 971
X86_INS_VPERMI2Q = 972
X86_INS_VPERMIL2PD = 973
X86_INS_VPERMIL2PS = 974
X86_INS_VPERMILPD = 975
X86_INS_VPERMILPS = 976
X86_INS_VPERMPD = 977
X86_INS_VPERMPS = 978
X86_INS_VPERMQ = 979
X86_INS_VPEXTRB = 980
X86_INS_VPEXTRD = 981
X86_INS_VPEXTRQ = 982
X86_INS_VPEXTRW = 983
X86_INS_VPGATHERDD = 984
X86_INS_VPGATHERDQ = 985
X86_INS_VPGATHERQD = 986
X86_INS_VPGATHERQQ = 987
X86_INS_VPHADDBD = 988
X86_INS_VPHADDBQ = 989
X86_INS_VPHADDBW = 990
X86_INS_VPHADDDQ = 991
X86_INS_VPHADDD = 992
X86_INS_VPHADDSW = 993
X86_INS_VPHADDUBD = 994
X86_INS_VPHADDUBQ = 995
X86_INS_VPHADDUBW = 996
X86_INS_VPHADDUDQ = 997
X86_INS_VPHADDUWD = 998
X86_INS_VPHADDUWQ = 999
X86_INS_VPHADDWD = 1000
X86_INS_VPHADDWQ = 1001
X86_INS_VPHADDW = 1002
X86_INS_VPHMINPOSUW = 1003
X86_INS_VPHSUBBW = 1004
X86_INS_VPHSUBDQ = 1005
X86_INS_VPHSUBD = 1006
X86_INS_VPHSUBSW = 1007
X86_INS_VPHSUBWD = 1008
X86_INS_VPHSUBW = 1009
X86_INS_VPINSRB = 1010
X86_INS_VPINSRD = 1011
X86_INS_VPINSRQ = 1012
X86_INS_VPINSRW = 1013
X86_INS_VPMACSDD = 1014
X86_INS_VPMACSDQH = 1015
X86_INS_VPMACSDQL = 1016
X86_INS_VPMACSSDD = 1017
X86_INS_VPMACSSDQH = 1018
X86_INS_VPMACSSDQL = 1019
X86_INS_VPMACSSWD = 1020
X86_INS_VPMACSSWW = 1021
X86_INS_VPMACSWD = 1022
X86_INS_VPMACSWW = 1023
X86_INS_VPMADCSSWD = 1024
X86_INS_VPMADCSWD = 1025
X86_INS_VPMADDUBSW = 1026
X86_INS_VPMADDWD = 1027
X86_INS_VPMASKMOVD = 1028
X86_INS_VPMASKMOVQ = 1029
X86_INS_VPMAXSB = 1030
X86_INS_VPMAXSD = 1031
X86_INS_VPMAXSW = 1032
X86_INS_VPMAXUB = 1033
X86_INS_VPMAXUD = 1034
X86_INS_VPMAXUW = 1035
X86_INS_VPMINSB = 1036
X86_INS_VPMINSD = 1037
X86_INS_VPMINSW = 1038
X86_INS_VPMINUB = 1039
X86_INS_VPMINUD = 1040
X86_INS_VPMINUW = 1041
X86_INS_VPMOVDB = 1042
X86_INS_VPMOVDW = 1043
X86_INS_VPMOVMSKB = 1044
X86_INS_VPMOVQB = 1045
X86_INS_VPMOVQD = 1046
X86_INS_VPMOVQW = 1047
X86_INS_VPMOVSDB = 1048
X86_INS_VPMOVSDW = 1049
X86_INS_VPMOVSQB = 1050
X86_INS_VPMOVSQD = 1051
X86_INS_VPMOVSQW = 1052
X86_INS_VPMOVSXBD = 1053
X86_INS_VPMOVSXBQ = 1054
X86_INS_VPMOVSXBW = 1055
X86_INS_VPMOVSXDQ = 1056
X86_INS_VPMOVSXWD = 1057
X86_INS_VPMOVSXWQ = 1058
X86_INS_VPMOVUSDB = 1059
X86_INS_VPMOVUSDW = 1060
X86_INS_VPMOVUSQB = 1061
X86_INS_VPMOVUSQD = 1062
X86_INS_VPMOVUSQW = 1063
X86_INS_VPMOVZXBD = 1064
X86_INS_VPMOVZXBQ = 1065
X86_INS_VPMOVZXBW = 1066
X86_INS_VPMOVZXDQ = 1067
X86_INS_VPMOVZXWD = 1068
X86_INS_VPMOVZXWQ = 1069
X86_INS_VPMULDQ = 1070
X86_INS_VPMULHRSW = 1071
X86_INS_VPMULHUW = 1072
X86_INS_VPMULHW = 1073
X86_INS_VPMULLD = 1074
X86_INS_VPMULLW = 1075
X86_INS_VPMULUDQ = 1076
X86_INS_VPORD = 1077
X86_INS_VPORQ = 1078
X86_INS_VPOR = 1079
X86_INS_VPPERM = 1080
X86_INS_VPROTB = 1081
X86_INS_VPROTD = 1082
X86_INS_VPROTQ = 1083
X86_INS_VPROTW = 1084
X86_INS_VPSADBW = 1085
X86_INS_VPSCATTERDD = 1086
X86_INS_VPSCATTERDQ = 1087
X86_INS_VPSCATTERQD = 1088
X86_INS_VPSCATTERQQ = 1089
X86_INS_VPSHAB = 1090
X86_INS_VPSHAD = 1091
X86_INS_VPSHAQ = 1092
X86_INS_VPSHAW = 1093
X86_INS_VPSHLB = 1094
X86_INS_VPSHLD = 1095
X86_INS_VPSHLQ = 1096
X86_INS_VPSHLW = 1097
X86_INS_VPSHUFB = 1098
X86_INS_VPSHUFD = 1099
X86_INS_VPSHUFHW = 1100
X86_INS_VPSHUFLW = 1101
X86_INS_VPSIGNB = 1102
X86_INS_VPSIGND = 1103
X86_INS_VPSIGNW = 1104
X86_INS_VPSLLDQ = 1105
X86_INS_VPSLLD = 1106
X86_INS_VPSLLQ = 1107
X86_INS_VPSLLVD = 1108
X86_INS_VPSLLVQ = 1109
X86_INS_VPSLLW = 1110
X86_INS_VPSRAD = 1111
X86_INS_VPSRAQ = 1112
X86_INS_VPSRAVD = 1113
X86_INS_VPSRAVQ = 1114
X86_INS_VPSRAW = 1115
X86_INS_VPSRLDQ = 1116
X86_INS_VPSRLD = 1117
X86_INS_VPSRLQ = 1118
X86_INS_VPSRLVD = 1119
X86_INS_VPSRLVQ = 1120
X86_INS_VPSRLW = 1121
X86_INS_VPSUBB = 1122
X86_INS_VPSUBD = 1123
X86_INS_VPSUBQ = 1124
X86_INS_VPSUBSB = 1125
X86_INS_VPSUBSW = 1126
X86_INS_VPSUBUSB = 1127
X86_INS_VPSUBUSW = 1128
X86_INS_VPSUBW = 1129
X86_INS_VPTESTMD = 1130
X86_INS_VPTESTMQ = 1131
X86_INS_VPTEST = 1132
X86_INS_VPUNPCKHBW = 1133
X86_INS_VPUNPCKHDQ = 1134
X86_INS_VPUNPCKHQDQ = 1135
X86_INS_VPUNPCKHWD = 1136
X86_INS_VPUNPCKLBW = 1137
X86_INS_VPUNPCKLDQ = 1138
X86_INS_VPUNPCKLQDQ = 1139
X86_INS_VPUNPCKLWD = 1140
X86_INS_VPXORD = 1141
X86_INS_VPXORQ = 1142
X86_INS_VPXOR = 1143
X86_INS_VRCP14PD = 1144
X86_INS_VRCP14PS = 1145
X86_INS_VRCP14SD = 1146
X86_INS_VRCP14SS = 1147
X86_INS_VRCPPS = 1148
X86_INS_VRCPSS = 1149
X86_INS_VRNDSCALESD = 1150
X86_INS_VRNDSCALESS = 1151
X86_INS_VRNDSCALEPD = 1152
X86_INS_VRNDSCALEPS = 1153
X86_INS_VROUNDPD = 1154
X86_INS_VROUNDPS = 1155
X86_INS_VROUNDSD = 1156
X86_INS_VROUNDSS = 1157
X86_INS_VRSQRT14PD = 1158
X86_INS_VRSQRT14PS = 1159
X86_INS_VRSQRT14SD = 1160
X86_INS_VRSQRT14SS = 1161
X86_INS_VRSQRTPS = 1162
X86_INS_VRSQRTSS = 1163
X86_INS_VSCATTERDPD = 1164
X86_INS_VSCATTERDPS = 1165
X86_INS_VSCATTERQPD = 1166
X86_INS_VSCATTERQPS = 1167
X86_INS_VSHUFPD = 1168
X86_INS_VSHUFPS = 1169
X86_INS_VSQRTPD = 1170
X86_INS_VSQRT = 1171
X86_INS_VSQRTPS = 1172
X86_INS_VSQRTSD = 1173
X86_INS_VSQRTSS = 1174
X86_INS_VSTMXCSR = 1175
X86_INS_VSUBPD = 1176
X86_INS_VSUBPS = 1177
X86_INS_VSUBSD = 1178
X86_INS_VSUBSS = 1179
X86_INS_VTESTPD = 1180
X86_INS_VTESTPS = 1181
X86_INS_VUNPCKHPD = 1182
X86_INS_VUNPCKHPS = 1183
X86_INS_VUNPCKLPD = 1184
X86_INS_VUNPCKLPS = 1185
X86_INS_VZEROALL = 1186
X86_INS_VZEROUPPER = 1187
X86_INS_WAIT = 1188
X86_INS_WBINVD = 1189
X86_INS_WRFSBASE = 1190
X86_INS_WRGSBASE = 1191
X86_INS_WRMSR = 1192
X86_INS_XABORT = 1193
X86_INS_XACQUIRE = 1194
X86_INS_XBEGIN = 1195
X86_INS_XCHG = 1196
X86_INS_FXCH = 1197
X86_INS_XCRYPTCBC = 1198
X86_INS_XCRYPTCFB = 1199
X86_INS_XCRYPTCTR = 1200
X86_INS_XCRYPTECB = 1201
X86_INS_XCRYPTOFB = 1202
X86_INS_XEND = 1203
X86_INS_XGETBV = 1204
X86_INS_XLATB = 1205
X86_INS_XRELEASE = 1206
X86_INS_XRSTOR = 1207
X86_INS_XRSTOR64 = 1208
X86_INS_XSAVE = 1209
X86_INS_XSAVE64 = 1210
X86_INS_XSAVEOPT = 1211
X86_INS_XSAVEOPT64 = 1212
X86_INS_XSETBV = 1213
X86_INS_XSHA1 = 1214
X86_INS_XSHA256 = 1215
X86_INS_XSTORE = 1216
X86_INS_XTEST = 1217

# all Intel instruction groups
X86_GRP_INVALID = 0
X86_GRP_3DNOW = 1
X86_GRP_AES = 2
X86_GRP_ADX = 3
X86_GRP_AVX = 4
X86_GRP_AVX2 = 5
X86_GRP_AVX512 = 6
X86_GRP_BMI = 7
X86_GRP_BMI2 = 8
X86_GRP_CMOV = 9
X86_GRP_F16C = 10
X86_GRP_FMA = 11
X86_GRP_FMA4 = 12
X86_GRP_FSGSBASE = 13
X86_GRP_HLE = 14
X86_GRP_MMX = 15
X86_GRP_MODE32 = 16
X86_GRP_MODE64 = 17
X86_GRP_RTM = 18
X86_GRP_SHA = 19
X86_GRP_SSE1 = 20
X86_GRP_SSE2 = 21
X86_GRP_SSE3 = 22
X86_GRP_SSE41 = 23
X86_GRP_SSE42 = 24
X86_GRP_SSE4A = 25
X86_GRP_SSSE3 = 26
X86_GRP_PCLMUL = 27
X86_GRP_XOP = 28
